------------------------------------------------------------------------------
-------------Insight 4.x to 5.0 migration script Instructions-----------------
------------------------------------------------------------------------------
--  1. BACKUP YOUR INSIGHT COLLECTION DATABASE! THIS SCRIPT IS NOT REVERSABLE.
--  2. Execute this script in Query Analyzer or isql for each collection 
--     database you plan on upgrading.
--  
--  This script performs a large number of modifications to your Collection
--  Manager database. It can take 3-15 minutes to execute, so be patient.
--  
--  If you encounter any errors please report these to Luna Imaging's support
--  department. support@luna-img.com or 1-800-452-LUNA (5862)
--
--  Not all Insight database schemas are identical and errors may occur. Every
--  effort has been made to identify variations in the Insight database schema.
--  If you do receive an error, contact Luna Imaging and one of our support 
--  personnel will identify and provide a correction for the problem.
--
------------------------------------------------------------------------------
--
------------------------------------------------------------------------------
-- Copyright (c) 1998-2004 Luna Imaging, Inc.  All Rights Reserved.
--
-- This software is confidential and proprietary information of
-- Luna Imaging, Inc.  ("Confidential Information").  You shall not
-- disclose such Confidential Information and shall use it only in
-- accordance with the terms of the license agreement you entered into
-- with Luna Imaging, Inc.
--
-- The software may not be copied, reproduced, translated or reduced to
-- any electronic medium or machine-readable form without
-- the prior written consent of Luna Imaging.
--
-- You are not allowed to distribute the binary and source code
-- (if released) to third parties, without the prior written consent from
-- Luna Imaging.
--
-- You are not allowed to reverse engineer, disassemble or decompile
-- code, or make any modifications of the binary or source code, remove
-- or alter any trademark, logo, copyright or other proprietary notices,
-- legends, symbols, or labels in the Software.
--
-- You are not allowed to sub-license the Software or any derivative
-- work based on or derived from the Software.
--
-- LUNA IMAGING MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
-- OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
-- TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-- PURPOSE, OR NON-INFRINGEMENT, LUNA IMAGING SHALL NOT BE LIABLE FOR ANY
-- DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
-- DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
------------------------------------------------------------------------------

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration script
----------------------------------------------------------------

--drop table UniqueCIDGenerator;
--drop table GenerateCCMEDIABATCHES;
--drop table GenerateIRGROUPS;
--drop table GenerateIRGROUPIMAGEMAP;
--drop table GenerateIRAPPROVALLEVELS;
--drop table GenerateISTables;
--drop table GenerateIREntityChanges;
--drop table GenerateISJOINS;
--drop table GenerateIRUserGroups;
--drop table GenerateIRObjectdimension;
--DROP PROCEDURE IndexPkeyRemove

----------------------------------------------------------------
-- SP_IndexPkeyRemove: Remove all index/primary keys for a table
----------------------------------------------------------------

CREATE PROCEDURE IndexPkeyRemove
  @tableName VARCHAR(40)
AS
  BEGIN

  IF OBJECT_ID('tempdb..#indexes') IS NOT NULL
    DROP TABLE #indexes
  CREATE TABLE #indexes (name SYSNAME, description VARCHAR(210), keys NVARCHAR(2078))

  --EXEC sp_helpindex @tableName

  INSERT INTO #indexes
  EXEC sp_helpindex @tableName

  DECLARE indexesCsr CURSOR FOR
  SELECT name, description, keys
  FROM #indexes
  FOR READ ONLY

  DECLARE @name CHAR(64)  --if you need NVARCHAR, use SYSNAME as datatype
  DECLARE @description VARCHAR(210)
  DECLARE @keys VARCHAR(1039)  --if you need NVARCHAR, use NVARCHAR(2078)
  DECLARE @name_clus CHAR(64)  --if you need NVARCHAR, use SYSNAME as datatype
  DECLARE @description_clus VARCHAR(210)
  DECLARE @keys_clus VARCHAR(1039)  --if you need NVARCHAR, use NVARCHAR(2078)

  --drop existing indexes, non-clustered first, then clustered, if any
  OPEN indexesCsr
  FETCH NEXT FROM indexesCsr INTO @name, @description, @keys
  WHILE @@FETCH_STATUS = 0
    BEGIN
    IF LEFT(@description, 9) = 'clustered'
      BEGIN
      SET @name_clus = @name
      SET @description_clus = @description
      SET @keys_clus = @keys
      END --IF
    ELSE
      BEGIN
      --PRINT 'DROP INDEX ' + RTRIM(@tableName) + '.' + @name
      --PRINT 'ALTER TABLE ' + RTRIM(@tableName) + ' DROP CONSTRAINT '  + @name
      IF (@description like '%primary key%')
        BEGIN
        --PRINT 'Primary Key found'
        EXEC('ALTER TABLE ' + @tableName + ' DROP CONSTRAINT ' + @name)
        END
      ELSE
        BEGIN
        EXEC('DROP INDEX ' + @tableName +'.' + @name)
        END
        -- IF

      END --ELSE
      FETCH NEXT FROM indexesCsr INTO @name, @description, @keys
    END --WHILE
    CLOSE indexesCsr
    DEALLOCATE indexesCsr
    IF @name_clus IS NOT NULL
      BEGIN
      --PRINT 'DROP INDEX ' + RTRIM(@tableName) + '.' + @name_clus

      IF (@description like '%primary key%')
        BEGIN
        --PRINT 'Primary Key found'
        EXEC('ALTER TABLE ' + @tableName + ' DROP CONSTRAINT ' + @name_clus)
        END
      ELSE
        BEGIN
        --IF
        --EXEC('ALTER TABLE ' + @tableName + ' DROP CONSTRAINT ' + @name_clus)
        --PRINT 'Primary Key NOT found'
        --PRINT 'DROP INDEX ' + RTRIM(@tableName) + '.' + @name_clus
        EXEC('DROP INDEX ' + @tableName + '.' + @name_clus)
      END

    END --IF
  END
GO

----------------------------------------------------------------
-- SP_RemoveDefaultValues: Remove Default value for a column
----------------------------------------------------------------

Create procedure RemoveDefaultValues
  @TableName varchar(255),
  @ColumnName varchar(255)
as
  begin
  DECLARE @defname VARCHAR(100), @cmd VARCHAR(1000)
  SET @defname =(
  SELECT name
  FROM sysobjects so JOIN sysconstraints sc
  ON so.id = sc.constid 
  WHERE object_name(so.parent_obj) = @TableName AND so.xtype = 'D' AND
  sc.colid = (SELECT colid FROM syscolumns
   WHERE id = object_id(@TableName) AND
   name = @ColumnName)
  )SET @cmd = 'ALTER TABLE '+ @TableName + ' DROP CONSTRAINT '
  + @defname
  EXEC(@cmd)
  end
go

----------------------------------------------------------------
-- Create log table for upgrade descriptive information
----------------------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'INSIGHTUPGRADELOG')
  BEGIN
  CREATE TABLE INSIGHTUPGRADELOG
    (
     Version NVARCHAR(10),
     TableName NVARCHAR(50),
     ChangeType NVARCHAR(10),
     ChangeIdentifier INT NOT NULL,
     Description NVARCHAR(255),
     CreatedTimeStamp DATETIME DEFAULT GETDATE()
    )
  ALTER TABLE INSIGHTUPGRADELOG ADD CONSTRAINT PK_INSIGHTUPGRADELOG PRIMARY KEY (CHANGEIDENTIFIER);
  END

----------------------------------------------------------------
-- Create IREVENTLOG
----------------------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IREVENTLOG')
  BEGIN
  CREATE TABLE IREVENTLOG
  (
    EVENTTYPE NVARCHAR(50) NULL,
    EVENTOWNER NVARCHAR(50) NULL,
    EVENTTIMETSTAMP NVARCHAR(32) NULL,
    EVENTSTATUS NVARCHAR(32) NULL,
    EVENTNOTES NVARCHAR(1000) NULL
  )
  END

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRCOLLECTIONCONFIGURATIONINFO
----------------------------------------------------------------
SET NOCOUNT ON

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'v4_IRCOLLECTIONCONFIGURATIONINFO')
  BEGIN
  SELECT * INTO v4_IRCOLLECTIONCONFIGURATIONINFO FROM IRCOLLECTIONCONFIGURATIONINFO

  CREATE TABLE UniqueCIDGenerator
    (
    UNIQUECOLLECTIONID int NOT NULL IDENTITY (1, 1),
    INSTITUTIONID nvarchar(50) NOT NULL,
    COLLECTIONID nvarchar(50) NOT NULL,
    VCID nvarchar(50) NOT NULL,
    NATIVESTANDARDID int
    );
    
  INSERT INTO UniqueCIDGenerator (INSTITUTIONID, COLLECTIONID, VCID) select INSTITUTIONID, COLLECTIONID, VCID from IRCOLLECTIONCONFIGURATIONINFO where VCID= 'NA';
  END

IF NOT EXISTS (SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table IRCOLLECTIONCONFIGURATIONINFO add
    UNIQUECOLLECTIONID int;
GO

IF NOT EXISTS (SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'NATIVESTANDARDID') 
  alter table IRCOLLECTIONCONFIGURATIONINFO add
    NATIVESTANDARDID int;
GO

IF NOT EXISTS (SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'CREATEDTIMESTAMP') 
  alter table IRCOLLECTIONCONFIGURATIONINFO add
    CREATEDTIMESTAMP nvarchar(32)
GO

IF EXISTS (SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'FRVURL') 
  alter table IRCOLLECTIONCONFIGURATIONINFO drop
    column FRVURL
GO

IF EXISTS (SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'PcStandardName') 
  alter table IRCOLLECTIONCONFIGURATIONINFO drop
    column PcStandardName
GO

IF EXISTS (SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'IsPcMediaShared') 
  alter table IRCOLLECTIONCONFIGURATIONINFO drop
    column IsPcMediaShared
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'BROWSERSECURITY' AND DATA_TYPE = 'int')
  alter table IRCOLLECTIONCONFIGURATIONINFO alter column
    BROWSERSECURITY int;

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'COUNTRYCODE' AND DATA_TYPE = 'nvarchar' AND CHARACTER_MAXIMUM_LENGTH = 50)
  alter table IRCOLLECTIONCONFIGURATIONINFO alter column
    COUNTRYCODE nvarchar(50);

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'LANGUAGECODE' AND DATA_TYPE = 'nvarchar' AND CHARACTER_MAXIMUM_LENGTH = 50)
  alter table IRCOLLECTIONCONFIGURATIONINFO alter column
    LANGUAGECODE nvarchar(50);

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'COPYRIGHTSTATEMENT' AND DATA_TYPE = 'nvarchar' AND CHARACTER_MAXIMUM_LENGTH = 255)
  alter table IRCOLLECTIONCONFIGURATIONINFO alter column
    COPYRIGHTSTATEMENT nvarchar(255);

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'FORCECOLLECTIONNAMEDISPLAY' AND DATA_TYPE = 'int')
  alter table IRCOLLECTIONCONFIGURATIONINFO alter column
    FORCECOLLECTIONNAMEDISPLAY int;

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'UniqueCIDGenerator')
  BEGIN
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 100)
    BEGIN
    UPDATE IRCOLLECTIONCONFIGURATIONINFO SET NATIVESTANDARDID = (SELECT DISTINCT StandardID FROM  SLStandardsLookup WHERE (Standard_Type = 1));
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRCOLLECTIONCONFIGURATIONINFO','UPDATE',100)
    END

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 110)
    BEGIN
    --UPDATE IRCOLLECTIONCONFIGURATIONINFO SET IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID = uniquecidgenerator.UNIQUECOLLECTIONID FROM IRCOLLECTIONCONFIGURATIONINFO,uniquecidgenerator WHERE (UniqueCIDGenerator.COLLECTIONID = IRCOLLECTIONCONFIGURATIONINFO.COLLECTIONID) AND (UniqueCIDGenerator.INSTITUTIONID = IRCOLLECTIONCONFIGURATIONINFO.INSTITUTIONID);
    UPDATE IRCOLLECTIONCONFIGURATIONINFO SET IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID = 1;
    
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRCOLLECTIONCONFIGURATIONINFO','UPDATE',110)
    END
  END
GO

IF EXISTS (SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  BEGIN
  alter table IRCOLLECTIONCONFIGURATIONINFO alter column
    UNIQUECOLLECTIONID int not null

  alter table IRCOLLECTIONCONFIGURATIONINFO alter column
    NATIVESTANDARDID int not null
  END
GO

IF EXISTS (SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'HelpGroup')
  BEGIN
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 120)
    BEGIN
    UPDATE IRCollectionConfigurationInfo SET HelpGroup='http://www.lunaimaging.com/v5_0help/insight/insight5.htm' WHERE HelpGroup like '%help-group.html' OR HelpGroup = '' OR HelpGroup  IS NULL
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRCOLLECTIONCONFIGURATIONINFO','UPDATE',120)
    END
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 130)
    BEGIN
    UPDATE IRCollectionConfigurationInfo SET HelpImage='http://www.lunaimaging.com/v5_0help/insight/insight5.htm' WHERE HelpImage like '%help-image.html' OR HelpImage = '' OR HelpImage  IS NULL
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRCOLLECTIONCONFIGURATIONINFO','UPDATE',130)
    END
  END
GO

IF EXISTS (SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONCONFIGURATIONINFO' AND COLUMN_NAME = 'CREATEDTIMESTAMP')
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 140)
    BEGIN
    UPDATE IRCOLLECTIONCONFIGURATIONINFO SET CREATEDTIMESTAMP = '20040616120000' WHERE (CREATEDTIMESTAMP IS NULL) OR (CREATEDTIMESTAMP = '')
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRCOLLECTIONCONFIGURATIONINFO','UPDATE',140)
    END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'UniqueCIDGenerator')
  DROP TABLE UniqueCIDGenerator
GO

UPDATE IRCOLLECTIONCONFIGURATIONINFO SET ISPERSONALCOLLECTION = 0 WHERE ISPERSONALCOLLECTION = '' OR ISPERSONALCOLLECTION IS NULL;

----------------------------------------------------------------
--Modify Collection to be entity aware.
--Test to see if system is inscribe aware
----------------------------------------------------------------


declare @TestISEntityTypes int

declare ISET cursor
   for select count(*) from ISEntityTypes

open ISET
fetch next from ISET into @TestISEntityTypes

close ISET
deallocate ISET

IF @TestISEntityTypes < 1
  BEGIN
  declare @PrimaryObjectTable varchar(50); 
  declare @PrimaryObjectTableID int;
  declare @PrimaryObjectKey varchar(50);
  set @PrimaryObjectTable = (SELECT TableName FROM ISTables WHERE IsPrimaryObjectTable = 1);
  set @PrimaryObjectTableID = (SELECT TableID FROM ISTables WHERE IsPrimaryObjectTable = 1);
  set @PrimaryObjectKey = (SELECT PrimaryObjectKey FROM ISTables WHERE IsPrimaryObjectTable = 1);
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 10)
    BEGIN
    insert into ISENTITYTYPES (ENTITYTYPEID,ENTITYTYPENAME,ENTITYTYPEDISPLAYNAME,ENTITYTABLEID,RESTRICTIONLEVEL,ENTITYIDCOLUMNNAME,ISPREFERREDENTITY,ENTITYTYPEDISPLAYORDER) VALUES (1, @PrimaryObjectTable, @PrimaryObjectTable, @PrimaryObjectTableID, -1, @PrimaryObjectKey, 1, 1)
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','ISENTITYTYPES','INSERT',10)
    END

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 20)
    BEGIN
    INSERT INTO ISENTITYFIELDS
                      (ENTITYTYPEID, FIELDID, JOINID, FIELDTABLEID, FIELDVALUECOLUMNNAME, PREFERREDVALUECOLUMNNAME, RESTRICTIONLEVEL, ISREQUIRED, 
                      INTEGERRANGE, ISVALUELISTALLOWED, MINAPPROVALTOADDNEWVALUE, REPEATVALUESALLOWED, DISPLAYINRELATEDENTITIES, 
                      ALWAYSVALIDATENEWVALUES)
    SELECT     1 AS EntityTypeID, FIELDID, JOINPATH AS JoinID, TABLEID AS FIELDTABLEID, FIELDNAME AS FIELDVALUECOLUMNNAME, 
                      PREFERREDFIELDNAME AS PREFERREDVALUECOLUMNNAME, 0 AS RestrictionLevel, 0 AS ISRequired, NULL AS IntegerRange, 
                      1 AS IsValueListAllowed, 0 AS MINAPPROVALTOADDNEWVALUE, 0 AS REPEATVALUESALLOWED, 0 AS DISPLAYINRELATEDENTITIES, 
                      0 AS ALWAYSVALIDATENEWVALUES
    FROM         IRFIELDS
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','ISENTITYFIELDS','INSERT',20)
    END
END

GO

----------------------------------------------------------------
-- Modifications for CCIMAGECREATIONRESOLUTIONS
----------------------------------------------------------------

EXECUTE IndexPkeyRemove 'CCIMAGECREATIONRESOLUTIONS'

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCIMAGECREATIONRESOLUTIONS' AND COLUMN_NAME = 'JPEGBRIGHTNESSENABLED' AND DATA_TYPE = 'int')
  alter table CCIMAGECREATIONRESOLUTIONS alter column
    JPEGBRIGHTNESSENABLED int;
go
IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCIMAGECREATIONRESOLUTIONS' AND COLUMN_NAME = 'JPEGEDGETRIMENABLED' AND DATA_TYPE = 'int')
  alter table CCIMAGECREATIONRESOLUTIONS alter column
    JPEGEDGETRIMENABLED int;
go
IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCIMAGECREATIONRESOLUTIONS' AND COLUMN_NAME = 'JPEGFORCEUPSIZE' AND DATA_TYPE = 'int')
  alter table CCIMAGECREATIONRESOLUTIONS alter column
    JPEGFORCEUPSIZE int;
go
IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCIMAGECREATIONRESOLUTIONS' AND COLUMN_NAME = 'SIDCOMPRESSIONENABLED' AND DATA_TYPE = 'int')
  alter table CCIMAGECREATIONRESOLUTIONS alter column
    SIDCOMPRESSIONENABLED int;
go
IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCIMAGECREATIONRESOLUTIONS' AND COLUMN_NAME = 'SIDZOOMLEVELSENABLED' AND DATA_TYPE = 'int')
  alter table CCIMAGECREATIONRESOLUTIONS alter column
    SIDZOOMLEVELSENABLED int;
go
IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCIMAGECREATIONRESOLUTIONS' AND COLUMN_NAME = 'SIDGAMMAENABLED' AND DATA_TYPE = 'int')
  alter table CCIMAGECREATIONRESOLUTIONS alter column
    SIDGAMMAENABLED int;
go
IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCIMAGECREATIONRESOLUTIONS' AND COLUMN_NAME = 'SIDWEIGHTENABLED' AND DATA_TYPE = 'int')
  alter table CCIMAGECREATIONRESOLUTIONS alter column
    SIDWEIGHTENABLED int;
go
-- Primary key

ALTER TABLE CCIMAGECREATIONRESOLUTIONS
  ADD CONSTRAINT PK_CCIMAGECRESOLGROUP
  PRIMARY KEY (RESOLUTIONSETID, RESOLUTIONSIZE);  
go
----------------------------------------------------------------
-- END Modifications for CCIMAGECREATIONRESOLUTIONS  
----------------------------------------------------------------

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for CCMEDIABATCHES
----------------------------------------------------------------


IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'v4_CCMEDIABATCHES' OR TABLE_NAME = 'v4_CCMEDIABATCHELEMENTS')
  BEGIN
  SELECT * INTO v4_CCMEDIABATCHES FROM CCMEDIABATCHES
  SELECT * INTO v4_CCMEDIABATCHELEMENTS FROM CCMEDIABATCHELEMENTS

  IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateCCMEDIABATCHES')
    CREATE TABLE GenerateCCMEDIABATCHES
    (
      UNIQUECOLLECTIONID INT NOT NULL,
      BATCHID INT NOT NULL,
      BATCHNAME NVARCHAR(50) NULL,
      BATCHSTATUS INT NULL,
      RESOLUTIONPROFILEID INT NULL,
      DESTDIR NVARCHAR(300) NULL,
      LPSDIR NVARCHAR(255) NULL,
      LOGFILEPATH NVARCHAR(300) NULL,
      MAPPINGFILEPATH NVARCHAR(300) NULL,
      MAPPINGFIELDID INT NULL,
      URLPREFIX NVARCHAR(100) NULL,
      SIDURLPREFIX NVARCHAR(100) NULL,
      STARTINGMEDIAID DECIMAL(18,0) NULL
    )

  --Generate new CCMEDIABATCHES for each UniqueCollectionID

  declare @i int
  declare @GroupID int
  declare @GroupCount int
  declare @GroupIncrement int
  declare @CountUCID int
  declare @UCIDIncrement int
  declare @name varchar(200)
  declare @MaxBatchElementID int
  declare @MBEIDitem int

  set @GroupIncrement = 1

  --
  declare MaxBatchElement cursor
    for SELECT MAX(BatchElementID) AS MaxBatchElementID
      FROM  CCMediaBatchElements


  open MaxBatchElement
  fetch next from MaxBatchElement into @MaxBatchElementID
  close MaxBatchElement
  deallocate MaxBatchElement
  --
  set @MaxBatchElementID = @MaxBatchElementID + 1




  --Get count of CCMEDIABATCHES to process

  declare GC cursor
    for select count(*) from CCMEDIABATCHES


  open GC   
  fetch next from GC into @GroupCount
  close GC
  deallocate GC

  --Get count of how many versions of MEDIA BATCHES should be created

  declare CUCID cursor
     for select count(distinct UniqueCollectionID) from IRCollectionConfigurationInfo

  open CUCID   
  fetch next from CUCID into @CountUCID
  close CUCID
  deallocate CUCID

  declare GID cursor
     for select BatchID from CCMEDIABATCHES

  --declare UCID cursor
     --for select distinct UniqueCollectionID from IRCollectionConfigurationInfo


  --Get MaxBatchID

  declare MaxBatchID cursor
   for select MaxBatchID from IRMaxIDs

  open MaxBatchID   

  fetch next from MaxBatchID into @i
  set @i = @i + 1
  close MaxBatchID
  deallocate MaxBatchID

  --open UCID
  --fetch next from UCID into @name

  open GID
  fetch next from GID into @GroupID

      declare @MaxBatchElementIDcount int
      declare @MaxBatchElementIDincrement int

  --while @@fetch_status = 0
  while @GroupIncrement <= @GroupCount
  begin

    declare UCID cursor
         for select distinct UniqueCollectionID from IRCollectionConfigurationInfo
    open UCID
    fetch next from UCID into @name
    set @UCIDIncrement = 0
    while @CountUCID <> @UCIDIncrement
      begin

        INSERT INTO GenerateCCMEDIABATCHES (UniquecollectionID, BATCHID, BATCHNAME, BATCHSTATUS, RESOLUTIONPROFILEID, DESTDIR, LPSDIR, LOGFILEPATH, MAPPINGFILEPATH, MAPPINGFIELDID, URLPREFIX, STARTINGMEDIAID) SELECT @name UniqueCollectionID, @i BATCHID , BATCHNAME, BATCHSTATUS, RESOLUTIONPROFILEID, DESTDIR, LPSDIR, LOGFILEPATH, MAPPINGFILEPATH, MAPPINGFIELDID, URLPREFIX, STARTINGMEDIAID FROM CCMEDIABATCHES where BATCHID = @GroupID
    
      set @MaxBatchElementIDincrement = 0
      declare MBEIDcount cursor
         for SELECT COUNT(BATCHELEMENTID) FROM CCMEDIABATCHELEMENTS WHERE BATCHID = @GroupID
      declare MBEID cursor
         for SELECT BATCHELEMENTID FROM CCMEDIABATCHELEMENTS WHERE BATCHID = @GroupID


      open MBEIDcount
      open MBEID

      fetch next from MBEIDcount into @MaxBatchElementIDcount
      fetch next from MBEID into @MBEIDitem

      while @MaxBatchElementIDincrement < @MaxBatchElementIDcount
         begin
         IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 30)
           INSERT INTO CCMEDIABATCHELEMENTS (BATCHELEMENTID, BATCHID, ELEMENTSTATUS, SRCFILEPATH, SRCFILENAME, DESTMEDIAID, OBJECTKEYFIELDID, OBJECTKEY) select @MaxBatchElementID BATCHELEMENTID, @i BATCHID, ELEMENTSTATUS, SRCFILEPATH, SRCFILENAME, DESTMEDIAID, OBJECTKEYFIELDID, OBJECTKEY from CCMEDIABATCHELEMENTS where BATCHID = @GroupID AND BATCHELEMENTID = @MBEIDitem
         set @MaxBatchElementIDincrement = @MaxBatchElementIDincrement + 1
         set @MaxBatchElementID = @MaxBatchElementID + 1
         fetch next from MBEID into @MBEIDitem
         end

      close MBEID
      deallocate MBEID

      close MBEIDcount
      deallocate MBEIDcount

        fetch next from UCID into @name
        set @UCIDIncrement = @UCIDIncrement + 1
      set @i = @i + 1
      end
        
      close UCID
    deallocate UCID
    set @GroupIncrement = @GroupIncrement + 1
    fetch next from GID into @GroupID
    --set @i = @i + 1
  end
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 30)
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','CCMEDIABATCHELEMENTS','INSERT',30)
  set @i = @i + 1
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 150)
    BEGIN
    UPDATE IRMaxIDs set MaxBatchID = @i
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRMaxIDs','UPDATE',150)
    END

  --close UCID
  --deallocate UCID

  close GID
  deallocate GID

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 470)
    BEGIN
    DROP TABLE CCMEDIABATCHES
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','CCMEDIABATCHES','DROP',470)
    END
END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateCCMEDIABATCHES')
  BEGIN
  SELECT * INTO CCMEDIABATCHES FROM GenerateCCMEDIABATCHES
  DROP TABLE GenerateCCMEDIABATCHES
  END
GO

ALTER TABLE CCMEDIABATCHES
  ADD CONSTRAINT PK_CCMEDIABATCHES
  PRIMARY KEY (BATCHID)
GO

EXECUTE IndexPkeyRemove 'CCMEDIABATCHELEMENTS'

ALTER TABLE CCMEDIABATCHELEMENTS ALTER COLUMN
    BatchID INT NOT NULL
GO

ALTER TABLE CCMEDIABATCHELEMENTS ALTER COLUMN
    BATCHELEMENTID DECIMAL(18,0) NOT NULL
GO

ALTER TABLE CCMEDIABATCHELEMENTS
  ADD CONSTRAINT PK_CCMEDIABATCHELEMENTS
  PRIMARY KEY (BATCHID, BATCHELEMENTID)
GO

CREATE INDEX IDX_MEDBELEM_BEID
  ON CCMEDIABATCHELEMENTS (BATCHELEMENTID);

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCMEDIABATCHELEMENTS' AND COLUMN_NAME = 'PROCESSEDTIMESTAMP')
  alter table CCMEDIABATCHELEMENTS add
    PROCESSEDTIMESTAMP nvarchar(32)
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCMEDIABATCHELEMENTS' AND COLUMN_NAME = 'LASTPUBLISHEDTIMESTAMP')
  alter table CCMEDIABATCHELEMENTS add
    LASTPUBLISHEDTIMESTAMP nvarchar(32)
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCMEDIABATCHELEMENTS' AND COLUMN_NAME = 'PROCESSEDTIMESTAMP')
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 160)
    BEGIN
    UPDATE CCMEDIABATCHELEMENTS SET PROCESSEDTIMESTAMP = '20040616120000' WHERE (PROCESSEDTIMESTAMP IS NULL) OR (PROCESSEDTIMESTAMP = '')
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','CCMEDIABATCHELEMENTS','UPDATE',160)
    END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCMEDIABATCHELEMENTS' AND COLUMN_NAME = 'LASTPUBLISHEDTIMESTAMP')
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 170)
    BEGIN
    UPDATE CCMEDIABATCHELEMENTS SET LASTPUBLISHEDTIMESTAMP = '20040616120000' WHERE (LASTPUBLISHEDTIMESTAMP IS NULL) OR (LASTPUBLISHEDTIMESTAMP = '')
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','CCMEDIABATCHELEMENTS','UPDATE',170)
    END
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CCMEDIABATCHELEMENTS' AND COLUMN_NAME = 'DESTMEDIAID' AND DATA_TYPE = 'decimal' AND NUMERIC_PRECISION = 18 AND NUMERIC_SCALE = 0)
alter table CCMEDIABATCHELEMENTS alter column
  DESTMEDIAID decimal(18,0);
GO


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRGROUPS
----------------------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'v4_IRGroups' OR TABLE_NAME = 'v4_IRGROUPIMAGEMAP')
  BEGIN
  SELECT * INTO v4_IRGroups FROM IRGROUPS
  SELECT * INTO v4_IRGROUPIMAGEMAP from IRGROUPIMAGEMAP

  IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateIRGROUPS')
  CREATE TABLE GenerateIRGROUPS
  (
    UNIQUECOLLECTIONID INT NOT NULL,
    GROUPID INT NOT NULL,
    BASE NVARCHAR(50) NULL,
    NAME NVARCHAR(50) NULL,
    GROUPTYPE INT NULL,
    VCID NVARCHAR(50) NOT NULL,
    CREATEDTIMESTAMP NVARCHAR(32) NULL,
    LASTMODIFIEDTIMESTAMP NVARCHAR(32) NULL
  );

  IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateIRGROUPIMAGEMAP')
  CREATE TABLE GenerateIRGROUPIMAGEMAP
  (
    GROUPID INT DEFAULT 1 NOT NULL,
    IMAGEID DECIMAL(18,0) NOT NULL,
    MVISERIES INT DEFAULT 0 NOT NULL,
    MPDSERIES INT DEFAULT 0 NOT NULL,
    ABSOLUTEORDER INT NULL,
    OBJECTID DECIMAL(18,0) NOT NULL
  );

  declare @Groups varchar(200)
  
  declare TempGroup cursor
     for select distinct groupid from IRGroups where grouptype=3
  
  open TempGroup
  fetch next from TempGroup into @Groups
  
  while @@fetch_status = 0
  begin
  
  delete IrgroupImageMap where groupid = @Groups
  
  delete Irgroups where groupid = @Groups
  
    fetch next from TempGroup into @Groups
  end
  close TempGroup
  deallocate TempGroup
  
  --Migrate Collection Groups
  
  insert into GenerateIRGROUPS (UniqueCollectionID, GroupID, Base, Name, GroupType, VCID)
  
  SELECT IRCollectionConfigurationInfo.UniqueCollectionID, IRGroups.GroupID, IRGroups.Base, IRGroups.Name, IRGroups.GroupType, IRGroups.VCID 
  FROM  IRCollectionConfigurationInfo INNER JOIN
                 IRGroups ON IRCollectionConfigurationInfo.VCID = IRGroups.VCID AND IRCollectionConfigurationInfo.InitialGroupOpen = IRGroups.Name
  WHERE (IRGroups.GroupType = 1)
  
  
  --Migrage Collection Groups that do not have an accioated collection and assign a -1 to UniqueCollectionID
  
  insert into GenerateIRGROUPS (UniqueCollectionID, GroupID, Base, Name, GroupType, VCID)
  
  SELECT  -1 UNIQUECOLLECTIONID, IRGROUPS.GROUPID, IRGROUPS.BASE, IRGROUPS.NAME, 
                 IRGROUPS.GROUPTYPE, IRGROUPS.VCID
  FROM  IRCOLLECTIONCONFIGURATIONINFO RIGHT OUTER JOIN
                 IRGROUPS ON IRCOLLECTIONCONFIGURATIONINFO.VCID = IRGROUPS.VCID AND 
                 IRCOLLECTIONCONFIGURATIONINFO.INITIALGROUPOPEN = IRGROUPS.NAME
  WHERE (IRGROUPS.GROUPTYPE = 1) AND (IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID IS NULL)


  --Generate new type 2 groups for each UniqueCollectionID
  
  declare @i int
  declare @GroupID int
  declare @GroupCount int
  declare @GroupIncrement int
  declare @CountUCID int
  declare @UCIDIncrement int
  declare @name varchar(200)

  set @GroupIncrement = 1


  --Get count of type 2 groups to process
  
  declare GC cursor
    for select count(*) from IRGroups where grouptype = 2
  
  
  open GC   
  fetch next from GC into @GroupCount
  close GC
  deallocate GC
  
  --Get count of how many versions of type 2 groups should be created
  
  declare CUCID cursor
     for select count(distinct UniqueCollectionID) from IRCollectionConfigurationInfo
  
  open CUCID   
  fetch next from CUCID into @CountUCID
  close CUCID
  deallocate CUCID
  
  declare GID cursor
     for select GroupID from IRGroups where grouptype = 2
  
  --declare UCID cursor
     --for select distinct UniqueCollectionID from IRCollectionConfigurationInfo
  
  
  --Get MaxGroupID
  
  declare MaxGroupID cursor
     for select MaxGroupID from IRMaxIDs
  
  open MaxGroupID   
  
  fetch next from MaxGroupID into @i
  set @i = @i + 1
  close MaxGroupID
  deallocate MaxGroupID
  
  --open UCID
  --fetch next from UCID into @name
  
  open GID
  fetch next from GID into @GroupID
  
  --while @@fetch_status = 0
  while @GroupIncrement <= @GroupCount
  begin
    
    declare UCID cursor
         for select distinct UniqueCollectionID from IRCollectionConfigurationInfo
    open UCID
    fetch next from UCID into @name
    --set @UCIDIncrement = 2
    set @UCIDIncrement = 0
    while @CountUCID <> @UCIDIncrement
      begin
      INSERT INTO GenerateIRGROUPS (UniquecollectionID, GROUPID, BASE, NAME, GROUPTYPE, VCID) SELECT @name UniqueCollectionID, @i GROUPID , BASE, NAME, GROUPTYPE, VCID FROM IRGROUPS where GroupID = @GroupID
      IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 40)
        INSERT INTO IRGROUPIMAGEMAP (GroupID, ImageID, MVISERIES, MPDSERIES) select @i GroupID, ImageID, MVISERIES, MPDSERIES from IRGroupImageMap where GroupID = @GroupID
      fetch next from UCID into @name
      set @UCIDIncrement = @UCIDIncrement + 1
      set @i = @i + 1
      end
        
      close UCID
    deallocate UCID
    set @GroupIncrement = @GroupIncrement + 1
    fetch next from GID into @GroupID
    --set @i = @i + 1
  end
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 40)
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRGROUPIMAGEMAP','INSERT',40)
  set @i = @i + 1
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 180)
    BEGIN
    UPDATE IRMaxIDs set MaxGroupID = @i
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','MaxGroupID','UPDATE',180)
    END
  --close UCID
  --deallocate UCID
  
  close GID
  deallocate GID

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 480)
    BEGIN
    DROP TABLE IRGroups
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRGroups','DROP',480)
    END
  END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateIRGROUPS')
  BEGIN
  SELECT * INTO IRGroups FROM GenerateIRGROUPS
  DROP TABLE GenerateIRGROUPS
  END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRGROUPS' AND COLUMN_NAME = 'CREATEDTIMESTAMP')
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 190)
    BEGIN
    UPDATE IRGROUPS SET CREATEDTIMESTAMP = '20040616120000' WHERE (CREATEDTIMESTAMP IS NULL) OR (CREATEDTIMESTAMP = '')
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRGROUPS','UPDATE',190)
    END
go

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRGROUPS' AND COLUMN_NAME = 'LASTMODIFIEDTIMESTAMP')
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 200)
    BEGIN
    UPDATE IRGROUPS SET LASTMODIFIEDTIMESTAMP = '20040616120000' WHERE (LASTMODIFIEDTIMESTAMP IS NULL) OR (LASTMODIFIEDTIMESTAMP = '')
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRGROUPS','UPDATE',200)
    END
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRGROUPS' AND COLUMN_NAME = 'NAME' AND DATA_TYPE = 'nvarchar' AND CHARACTER_MAXIMUM_LENGTH = 255)
  alter table IRGROUPS alter column
    NAME nvarchar(255)
go

-- Primary key

ALTER TABLE IRGROUPS
  ADD CONSTRAINT PK_IRGROUPS
  PRIMARY KEY (GROUPID);
go


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRGROUPIMAGEMAP
----------------------------------------------------------------

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateIRGROUPIMAGEMAP')
  BEGIN
  insert into GenerateIRGROUPIMAGEMAP (GROUPID, IMAGEID, MVISERIES, MPDSERIES, OBJECTID) SELECT DISTINCT IRGroupImageMap.GroupID, IRGroupImageMap.ImageID, IRGroupImageMap.MviSeries, 
                 IRGroupImageMap.MpdSeries, IRObjectImageMap.ObjectID
  FROM  IRGroupImageMap INNER JOIN
                 IRObjectImageMap ON IRGroupImageMap.ImageID = IRObjectImageMap.ImageID

  insert into GenerateIRGROUPIMAGEMAP (GROUPID, IMAGEID, MVISERIES, MPDSERIES, OBJECTID) SELECT DISTINCT IRGroupImageMap.GroupID, IRGroupImageMap.ImageID, IRGroupImageMap.MviSeries, IRGroupImageMap.MpdSeries, 
                 0 AS ObjectID
  FROM  IRGroupImageMap LEFT OUTER JOIN
                 IRObjectImageMap ON IRGroupImageMap.ImageID = IRObjectImageMap.ImageID
  WHERE (IRObjectImageMap.ObjectID IS NULL)

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 490)
    BEGIN
    DROP TABLE IRGROUPIMAGEMAP
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRGROUPIMAGEMAP','DROP',490)
    END
  END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateIRGROUPIMAGEMAP')
  BEGIN
  SELECT * INTO IRGROUPIMAGEMAP FROM GenerateIRGROUPIMAGEMAP
  DROP TABLE GenerateIRGROUPIMAGEMAP
  END
GO

-- Primary key

ALTER TABLE IRGROUPIMAGEMAP
  ADD CONSTRAINT PK_IRGROUPIMAGEMAP
  PRIMARY KEY (GROUPID, IMAGEID, OBJECTID, MVISERIES, MPDSERIES);
go

CREATE INDEX IDX_IRGRPIMGMAP_OBJIDGRPID
  ON IRGROUPIMAGEMAP (OBJECTID, GROUPID);
go




----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTENTITYTOENTITYMAP
----------------------------------------------------------------


TRUNCATE TABLE DTENTITYTOENTITYMAP

EXECUTE IndexPkeyRemove 'DTENTITYTOENTITYMAP'

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DTENTITYTOENTITYMAP' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table DTENTITYTOENTITYMAP add
    UNIQUECOLLECTIONID int;
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DTENTITYTOENTITYMAP' AND COLUMN_NAME = 'UNIQUECOLLECTIONID' AND IS_NULLABLE = 'No')
  alter table DTENTITYTOENTITYMAP alter column
    UNIQUECOLLECTIONID int not null
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DTENTITYTOENTITYMAP' AND COLUMN_NAME = 'ENTITYID' AND DATA_TYPE = 'decimal' AND NUMERIC_PRECISION = 18 AND NUMERIC_SCALE = 0 AND IS_NULLABLE = 'No')
  alter table DTENTITYTOENTITYMAP alter column
    ENTITYID DECIMAL(18,0) NOT NULL;
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DTENTITYTOENTITYMAP' AND COLUMN_NAME = 'RELENTITYID' AND DATA_TYPE = 'decimal' AND NUMERIC_PRECISION = 18 AND NUMERIC_SCALE = 0 AND IS_NULLABLE = 'No')
  alter table DTENTITYTOENTITYMAP alter column
    RELENTITYID DECIMAL(18,0) NOT NULL;
go

-- Primary key

ALTER TABLE DTENTITYTOENTITYMAP
  ADD CONSTRAINT PK_DTENTITYTOENTITYMAP
  PRIMARY KEY (ENTITYTYPEID, ENTITYID, RELENTITYTYPEID, RELENTITYID); 
go

CREATE INDEX IDX_DTETOEMAP_REL
  ON DTENTITYTOENTITYMAP (RELENTITYTYPEID, RELENTITYID);

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTFLATOBJECTDATA
----------------------------------------------------------------


TRUNCATE TABLE DTFLATOBJECTDATA;

EXECUTE IndexPkeyRemove 'DTFLATOBJECTDATA'

alter table DTFlatObjectData alter column
  OBJECTID decimal(18,0) not null;
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DTFLATOBJECTDATA' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table DTFLATOBJECTDATA add
    UNIQUECOLLECTIONID int;
go

alter table DTFLATOBJECTDATA alter column
  UNIQUECOLLECTIONID int not null
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DTFLATOBJECTDATA' AND COLUMN_NAME = 'SORTDATAVAL')
  alter table DTFLATOBJECTDATA add
    SORTDATAVAL NVARCHAR(400);
GO

alter table DTFLATOBJECTDATA ALTER COLUMN
  THUMBDATA1 NVARCHAR(100);

alter table DTFLATOBJECTDATA ALTER COLUMN
  THUMBDATA2 NVARCHAR(100);

alter table DTFLATOBJECTDATA ALTER COLUMN
  THUMBDATA3 NVARCHAR(100);

alter table DTFLATOBJECTDATA ALTER COLUMN
  THUMBDATA4 NVARCHAR(100);

alter table DTFLATOBJECTDATA ALTER COLUMN
  SORTDATA1 NVARCHAR(100);

alter table DTFLATOBJECTDATA ALTER COLUMN
  SORTDATA2 NVARCHAR(100);

alter table DTFLATOBJECTDATA ALTER COLUMN
  SORTDATA3 NVARCHAR(100);

alter table DTFLATOBJECTDATA ALTER COLUMN
  SORTDATA4 NVARCHAR(100);

-- Primary key and indexes

ALTER TABLE DTFLATOBJECTDATA
  ADD CONSTRAINT PK_DTFLATOBJECTDATA
  PRIMARY KEY (OBJECTID);
go

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTTERMOBJECTMAP
----------------------------------------------------------------

TRUNCATE TABLE DTTERMOBJECTMAP

EXECUTE IndexPkeyRemove 'DTTERMOBJECTMAP'

alter table DTTERMOBJECTMAP alter column
  OBJECTID decimal(18,0) not null;
go
alter table DTTERMOBJECTMAP alter column
  GROUPING decimal(18,0) not null;
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DTTERMOBJECTMAP' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table DTTERMOBJECTMAP add
    UNIQUECOLLECTIONID int;
go

alter table DTTERMOBJECTMAP alter column
  UNIQUECOLLECTIONID int not null
go  
-- Indexes

CREATE INDEX IDX_DTTRMOBJMAP_TERMIDOBJID
  ON DTTERMOBJECTMAP (TERMID, OBJECTID);

CREATE INDEX IDX_DTTRMOBJMAP_FLDIDTERMID
  ON DTTERMOBJECTMAP (FIELDID, TERMID);

CREATE INDEX IDX_DTTRMOBJMAPOBJ
  ON DTTERMOBJECTMAP (OBJECTID);

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTTERMTOENTITYMAP
----------------------------------------------------------------

TRUNCATE TABLE DTTERMTOENTITYMAP

EXECUTE IndexPkeyRemove 'DTTERMTOENTITYMAP'

alter table DTTERMTOENTITYMAP alter column
  GROUPING decimal(18,0) not null;
go
alter table DTTERMTOENTITYMAP alter column
  ENTITYID DECIMAL(18,0) NOT NULL;
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DTTERMTOENTITYMAP' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table DTTERMTOENTITYMAP add
    UNIQUECOLLECTIONID int;
go

alter table DTTERMTOENTITYMAP alter column
  UNIQUECOLLECTIONID int not null
go

ALTER TABLE DTTERMTOENTITYMAP
  ADD CONSTRAINT PK_DTTERMTOENTITYMAP
  PRIMARY KEY (UNIQUECOLLECTIONID, TERMID, ENTITYTYPEID, ENTITYID, FIELDID, GROUPING)
go

CREATE INDEX IDX_DTTTOEMAP_ETE
  ON DTTERMTOENTITYMAP (ENTITYTYPEID, ENTITYID);


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTVALUES
----------------------------------------------------------------

EXECUTE IndexPkeyRemove 'DTVALUES'

TRUNCATE TABLE DTVALUES

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DTVALUES' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table DTVALUES add
    UNIQUECOLLECTIONID int;
go

alter table DTVALUES alter column
  UNIQUECOLLECTIONID int not null
go

alter table DTVALUES alter column
  VALUEID decimal(18,0) not null
go

CREATE INDEX IDX_DTVAL_FLDIDVALID
  ON DTVALUES (FIELDID, UNIQUECOLLECTIONID, VALUEID)
go

create index IDX_DTVAL_VALIDFLDIDENBLD on DTVALUES(VALUEID,FIELDID,ENABLED)
go



----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTVALUETOENTITYMAP
----------------------------------------------------------------

TRUNCATE TABLE DTVALUETOENTITYMAP

EXECUTE IndexPkeyRemove 'DTVALUETOENTITYMAP'

alter table DTVALUETOENTITYMAP alter column
  ENTITYID DECIMAL(18,0) NOT NULL;
go
alter table DTVALUETOENTITYMAP alter column
  RELENTITYID DECIMAL(18,0) NOT NULL;
go  
alter table DTVALUETOENTITYMAP alter column
  PARENTENTITYID DECIMAL(18,0) NOT NULL;
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DTVALUETOENTITYMAP' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table DTVALUETOENTITYMAP add
    UNIQUECOLLECTIONID int;
go

alter table DTVALUETOENTITYMAP alter column
  UNIQUECOLLECTIONID int not null
go

alter table DTVALUETOENTITYMAP alter column
  VALUEID decimal(18,0) not null
go

ALTER TABLE DTVALUETOENTITYMAP
  ADD CONSTRAINT PK_DTVALUETOENTITY
  PRIMARY KEY (VALUEID, ENTITYTYPEID, ENTITYID, RELENTITYTYPEID, RELENTITYID, UNIQUECOLLECTIONID, PARENTENTITYTYPEID, PARENTENTITYID);
go

CREATE INDEX IDX_DTVALUETOENTITYMAP_01
  ON DTVALUETOENTITYMAP (EntityID, EntityTypeID);

CREATE INDEX IDX_DTVALUETOENTITYMAP_02
  ON DTVALUETOENTITYMAP (Preferred, EntityID);


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTVALUETOOBJECT
----------------------------------------------------------------

TRUNCATE TABLE DTVALUETOOBJECT

EXECUTE IndexPkeyRemove 'DTVALUETOOBJECT'

alter table DTVALUETOOBJECT alter column
  OBJECTID decimal(18,0) not null;
go
alter table DTVALUETOOBJECT alter column
  GROUPING decimal(18,0) not null;
go

alter table DTVALUETOOBJECT alter column
  VALUEID decimal(18,0) not null
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DTVALUETOOBJECT' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table DTVALUETOOBJECT add
    UNIQUECOLLECTIONID int;
go

alter table DTVALUETOOBJECT alter column
  UNIQUECOLLECTIONID int not null
go

ALTER TABLE DTVALUETOOBJECT
  ADD CONSTRAINT PK_DTVALUETOOBJECT
  PRIMARY KEY (VALUEID, OBJECTID, GROUPING);
go

CREATE UNIQUE INDEX IDX_DTVALTOOBJ_OBJIDVALIDGRP
  ON DTVALUETOOBJECT (OBJECTID, VALUEID, GROUPING);

CREATE INDEX IDX_DTVALTOOBJ_PFRDOBJIDVALID
  ON DTVALUETOOBJECT (PREFERRED, VALUEID, OBJECTID);


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITENTITYTOENTITYMAP
----------------------------------------------------------------


TRUNCATE TABLE ITENTITYTOENTITYMAP

EXECUTE IndexPkeyRemove 'ITENTITYTOENTITYMAP'

alter table ITENTITYTOENTITYMAP alter column
  ENTITYID DECIMAL(18,0) NOT NULL;
go  
alter table ITENTITYTOENTITYMAP alter column
  RELENTITYID DECIMAL(18,0) NOT NULL;
go  

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'ITENTITYTOENTITYMAP' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table ITENTITYTOENTITYMAP add
    UNIQUECOLLECTIONID int;
go

alter table ITENTITYTOENTITYMAP alter column
  UNIQUECOLLECTIONID int NOT NULL;
go  
-- Primary key

ALTER TABLE ITENTITYTOENTITYMAP
  ADD CONSTRAINT PK_ITENTITYTOENTITYMAP
  PRIMARY KEY (ENTITYTYPEID, ENTITYID, RELENTITYTYPEID, RELENTITYID);
go
CREATE INDEX IDX_ENTTOENTYMP_RLIDRLTYPID
  ON ITENTITYTOENTITYMAP (RELENTITYID, RELENTITYTYPEID);



----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITTERMOBJECTMAP
----------------------------------------------------------------

TRUNCATE TABLE ITTERMOBJECTMAP

EXECUTE IndexPkeyRemove 'ITTERMOBJECTMAP'

alter table ITTERMOBJECTMAP alter column
  OBJECTID decimal(18,0) not null;
go
alter table ITTERMOBJECTMAP alter column
  GROUPING decimal(18,0) not null;
go 
-- Indexes

-- Primary key

CREATE INDEX IDX_ITTRMOBJCTMAP_TRMID
  ON ITTERMOBJECTMAP (TERMID);

--CREATE INDEX IDX_ITTRMOBJMAP_TERMIDOBJID
--  ON ITTERMOBJECTMAP (TERMID, OBJECTID);

--CREATE INDEX IDX_ITTRMOBJMAP_FLDIDTERMID
--  ON ITTERMOBJECTMAP (FIELDID, TERMID);
 
IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'ITTERMOBJECTMAP' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table ITTERMOBJECTMAP add
    UNIQUECOLLECTIONID int;
go

alter table ITTERMOBJECTMAP alter column
  UNIQUECOLLECTIONID int not null
go


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITTERMTOENTITYMAP
----------------------------------------------------------------

TRUNCATE TABLE ITTERMTOENTITYMAP

EXECUTE IndexPkeyRemove 'ITTERMTOENTITYMAP'

alter table ITTERMTOENTITYMAP alter column
  ENTITYID DECIMAL(18,0) NOT NULL;
go
alter table ITTERMTOENTITYMAP alter column
  GROUPING decimal(18,0) not null;
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'ITTERMTOENTITYMAP' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table ITTERMTOENTITYMAP add
    UNIQUECOLLECTIONID int;
go

alter table ITTERMTOENTITYMAP alter column
  UNIQUECOLLECTIONID int not null
go

-- Primary key

ALTER TABLE ITTERMTOENTITYMAP
  ADD CONSTRAINT PK_ITTERMTOENTITYMAP
  PRIMARY KEY (TERMID, ENTITYTYPEID, ENTITYID, FIELDID, GROUPING);
go

CREATE INDEX IDX_DTTEM_ETEID
  ON ITTERMTOENTITYMAP (ENTITYTYPEID, ENTITYID);

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITVALUES
----------------------------------------------------------------

TRUNCATE TABLE ITVALUES

EXECUTE IndexPkeyRemove 'ITVALUES'

alter table ITVALUES alter column
  VALUEID decimal(18,0) not null
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'ITVALUES' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table ITVALUES add
    UNIQUECOLLECTIONID int;
go

alter table ITVALUES alter column
  UNIQUECOLLECTIONID int not null
go

-- Primary key

CREATE INDEX IDX_ITVALUES_VALIDFLDID
  ON ITVALUES (VALUEID, FIELDID);

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITVALUETOENTITYMAP
----------------------------------------------------------------

TRUNCATE TABLE ITVALUETOENTITYMAP

EXECUTE IndexPkeyRemove 'ITVALUETOENTITYMAP'

alter table ITVALUETOENTITYMAP alter column
  VALUEID decimal(18,0) not null;
go

alter table ITVALUETOENTITYMAP alter column
  ENTITYID DECIMAL(18,0) NOT NULL;
go  
alter table ITVALUETOENTITYMAP alter column
  RELENTITYID DECIMAL(18,0) NOT NULL;
go  
alter table ITVALUETOENTITYMAP alter column
  PARENTENTITYID DECIMAL(18,0) NOT NULL;
go  

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'ITVALUETOENTITYMAP' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table ITVALUETOENTITYMAP add
    UNIQUECOLLECTIONID int;
go

alter table ITVALUETOENTITYMAP alter column
  UNIQUECOLLECTIONID int not null
go

ALTER TABLE ITVALUETOENTITYMAP
  ADD CONSTRAINT PK_ITVALUETOENTITYMAP
  PRIMARY KEY (VALUEID, ENTITYTYPEID, ENTITYID, RELENTITYTYPEID, RELENTITYID, PARENTENTITYTYPEID, PARENTENTITYID);
go

CREATE INDEX IDX_ITVALTOENTMP_ENTIDENTTPID
  ON ITVALUETOENTITYMAP (ENTITYTYPEID, ENTITYID);


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITVALUETOOBJECT
----------------------------------------------------------------

TRUNCATE TABLE ITVALUETOOBJECT

EXECUTE IndexPkeyRemove 'ITVALUETOOBJECT'

alter table ITValueToObject alter column
  OBJECTID decimal(18,0) not null;
go
alter table ITValueToObject alter column
  GROUPING decimal(18,0) not null;
go  
-- Primary key

--ALTER TABLE ITVALUETOOBJECT
--  ADD CONSTRAINT PK_ITVALUETOOBJECT
--  PRIMARY KEY (VALUEID, OBJECTID, GROUPING);

--CREATE UNIQUE INDEX IDX_ITVALTOOBJ_OBJIDVALIDGRP
-- ON ITVALUETOOBJECT (OBJECTID, VALUEID, GROUPING);

--CREATE INDEX IDX_ITVALTOOBJ_PFRDOBJIDVALID
--  ON ITVALUETOOBJECT (PREFERRED, OBJECTID, VALUEID);

-- Primary key

CREATE INDEX IDX_ITVALUETOOBJECT_VALID
  ON ITVALUETOOBJECT (VALUEID);

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'ITVALUETOOBJECT' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  alter table ITVALUETOOBJECT add
    UNIQUECOLLECTIONID int;
go

alter table ITVALUETOOBJECT alter column
  UNIQUECOLLECTIONID int not null;
go

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRAPPROVALLEVELS
----------------------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'v4_IRAPPROVALLEVELS')
  BEGIN
  SELECT * INTO v4_IRAPPROVALLEVELS FROM IRAPPROVALLEVELS;

  EXECUTE RemoveDefaultValues 'IRAPPROVALLEVELS','COMMITTOINVERTEDDATA'
  EXECUTE RemoveDefaultValues 'IRAPPROVALLEVELS','COMMITTOSOURCEDATA'

  CREATE TABLE GenerateIRAPPROVALLEVELS (
    APPROVALLEVEL int not null,
    COMMITTOINVERTEDDATA int,
    COMMITTOSOURCEDATA int,
    UNIQUECOLLECTIONID int not null
  );

  insert into GenerateIRAPPROVALLEVELS (APPROVALLEVEL, COMMITTOINVERTEDDATA, COMMITTOSOURCEDATA, UNIQUECOLLECTIONID) 
  SELECT DISTINCT IRAPPROVALLEVELS.ApprovalLevel, IRAPPROVALLEVELS.CommitToInvertedData, IRAPPROVALLEVELS.CommitToSourceData, IRCollectionConfigurationInfo.UNIQUECOLLECTIONID FROM  IRCollectionConfigurationInfo CROSS JOIN IRAPPROVALLEVELS;

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 500)
    BEGIN
    DROP TABLE IRAPPROVALLEVELS;
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRAPPROVALLEVELS','DROP',500)
    END
  END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateIRAPPROVALLEVELS')
  BEGIN
  SELECT * INTO IRAPPROVALLEVELS FROM GenerateIRAPPROVALLEVELS;
  DROP TABLE GenerateIRAPPROVALLEVELS;
  END
GO
  
-- Primary key

ALTER TABLE IRAPPROVALLEVELS
  ADD CONSTRAINT PK_IRAPPROVALLEVELS
  PRIMARY KEY (UNIQUECOLLECTIONID, APPROVALLEVEL);
go

--------------------------------------------------------
-- Create Table Statements for SLCOLLECTIONSTANDARDMAP
--------------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SLCOLLECTIONSTANDARDMAP')
  BEGIN
  CREATE TABLE SLCOLLECTIONSTANDARDMAP
  (
    UNIQUECOLLECTIONID INT NOT NULL,
    STANDARDID INT NOT NULL,
    STANDARDS_ORDER INT NOT NULL
  );
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 50)
    BEGIN
    INSERT INTO SLCOLLECTIONSTANDARDMAP (UNIQUECOLLECTIONID, STANDARDID, STANDARDS_ORDER) SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID, SLStandardsLookup.StandardID, SLStandardsLookup.Standards_Order FROM SLStandardsLookup, IRCOLLECTIONCONFIGURATIONINFO WHERE SLStandardsLookup.Enabled = 1
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLCOLLECTIONSTANDARDMAP','INSERT',50)
    END
  END

-- Primary key

ALTER TABLE SLCOLLECTIONSTANDARDMAP
  ADD CONSTRAINT PK_SLCOLLECTIONSTANDARDMAP
  PRIMARY KEY (UNIQUECOLLECTIONID, STANDARDID);
go

------------------------------------------------
-- Create Table Statements for ISTEMPLATEENTITYTYPEMAP
------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'ISTEMPLATEENTITYTYPEMAP')
  BEGIN
  CREATE TABLE ISTEMPLATEENTITYTYPEMAP
  (
    TEMPLATEID INT NOT NULL,
    ENTITYTYPEID INT NOT NULL
  );

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 60)
    BEGIN
    INSERT INTO  ISTEMPLATEENTITYTYPEMAP (TEMPLATEID, ENTITYTYPEID) SELECT (SELECT StandardID FROM SLStandardsLookup WHERE Standard_Type = 1) TEMPLATEID, EntityTypeID FROM ISEntityTypes
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','ISTEMPLATEENTITYTYPEMAP','INSERT',60)
    END
  END
GO

-- Primary key

ALTER TABLE ISTEMPLATEENTITYTYPEMAP
  ADD CONSTRAINT PK_ISTEMPLATEENTITYTYPEMAP
  PRIMARY KEY (ENTITYTYPEID, TEMPLATEID);
go


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ISTables
----------------------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'v4_ISTables')
  BEGIN
  SELECT * INTO v4_ISTables FROM ISTables

  CREATE TABLE GenerateISTables
    (
    UNIQUECOLLECTIONID int not null,
    TABLEID  int,
    COLLECTIONID int,
    TABLENAME nvarchar(50),
    HIERARCHY nvarchar(50),
    PARENTCHILD nvarchar(50),
    ISPRIMARYOBJECTTABLE INT,
    PRIMARYOBJECTKEY nvarchar(50)
    )

  INSERT INTO GenerateISTables (UNIQUECOLLECTIONID,TABLEID,COLLECTIONID,TABLENAME,HIERARCHY,PARENTCHILD,ISPRIMARYOBJECTTABLE,PRIMARYOBJECTKEY)
  SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID,ISTables.TABLEID,ISTables.COLLECTIONID,ISTables.TABLENAME,ISTables.HIERARCHY,ISTables.PARENTCHILD,ISTables.ISPRIMARYOBJECTTABLE,ISTables.PRIMARYOBJECTKEY from IRCOLLECTIONCONFIGURATIONINFO, ISTables

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 510)
    BEGIN
    DROP TABLE ISTables
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','ISTables','DROP',510)
    END
  END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateISTables')
  BEGIN
  SELECT * INTO ISTables FROM GenerateISTables
  DROP TABLE GenerateISTables
  END
GO

alter table ISTABLES alter column
  UNIQUECOLLECTIONID int not null
go

alter table ISTABLES alter column
  TABLEID int not null
go

alter table ISTABLES add
  constraint PK_ISTABLES primary key(UNIQUECOLLECTIONID,TABLEID)
go


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IREntityChanges
----------------------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'v4_IREntityChanges')
  BEGIN
  SELECT * INTO v4_IREntityChanges FROM IREntityChanges

  EXECUTE RemoveDefaultValues 'IRENTITYCHANGES', 'COMMITTEDTOINVERTEDDATA'
  EXECUTE RemoveDefaultValues 'IRENTITYCHANGES', 'COMMITTEDTOSOURCEDATA'
  EXECUTE RemoveDefaultValues 'IRENTITYCHANGES', 'LASTEDITORUSERID'

  CREATE TABLE GenerateIREntityChanges
    (
    UNIQUECOLLECTIONID int,
    CHANGEID int NOT NULL IDENTITY (1, 1),
    CHANGECATEGORY int,
    CHANGETYPE int,
    CHANGESTATUS int,
    APPROVALLEVEL int,
    COMMITTEDTOINVERTEDDATA int,
    COMMITTEDTOSOURCEDATA int,
    ENTITYTYPEID int,
    ENTITYID decimal(18,0),
    USERID int,
    CHANGETIMESTAMP  nvarchar(32),
    LASTEDITORUSERID int,
    LASTEDITORTIMESTAMP nvarchar(32),
    FIELDID  int,
    VALUECHANGE nvarchar(4000),
    RELENTITYTYPEID  int,
    RELENTITYID decimal(18,0),
    MEDIAID  decimal(18,0),
    METADATA nvarchar(255),
    CHANGECOMMENT nvarchar(1000)
    )

  INSERT INTO GenerateIREntityChanges (UNIQUECOLLECTIONID,CHANGECATEGORY,CHANGETYPE,CHANGESTATUS,APPROVALLEVEL,COMMITTEDTOINVERTEDDATA,COMMITTEDTOSOURCEDATA,ENTITYTYPEID,ENTITYID,USERID,CHANGETIMESTAMP,LASTEDITORUSERID,LASTEDITORTIMESTAMP,FIELDID,VALUECHANGE,RELENTITYTYPEID,RELENTITYID,MEDIAID,METADATA)

  SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID,IREntityChanges.CHANGECATEGORY,IREntityChanges.CHANGETYPE,IREntityChanges.CHANGESTATUS,IREntityChanges.APPROVALLEVEL,IREntityChanges.COMMITTEDTOINVERTEDDATA,IREntityChanges.COMMITTEDTOSOURCEDATA,IREntityChanges.ENTITYTYPEID,IREntityChanges.ENTITYID,IREntityChanges.USERID,IREntityChanges.CHANGETIMESTAMP,IREntityChanges.LASTEDITORUSERID,IREntityChanges.LASTEDITORTIMESTAMP,IREntityChanges.FIELDID,IREntityChanges.VALUECHANGE,IREntityChanges.RELENTITYTYPEID,IREntityChanges.RELENTITYID,IREntityChanges.MEDIAID,IREntityChanges.METADATA FROM IRCOLLECTIONCONFIGURATIONINFO, IREntityChanges
  --WHERE IREntityChanges.COMMITTEDTOSOURCEDATA = 0 OR IREntityChanges.COMMITTEDTOINVERTEDDATA = 0

  --UPDATE GenerateIREntityChanges SET COMMITTEDTOSOURCEDATA = -1 WHERE COMMITTEDTOSOURCEDATA = 1
  --UPDATE GenerateIREntityChanges SET COMMITTEDTOINVERTEDDATA = -1 WHERE COMMITTEDTOINVERTEDDATA = 1


  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 520)
    BEGIN
    DROP TABLE IREntityChanges
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IREntityChanges','DROP',520)
    END
  END
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IREntityChanges')
  CREATE TABLE IRENTITYCHANGES
  (
    UNIQUECOLLECTIONID INT NOT NULL,
    CHANGEID INT NOT NULL,
    CHANGECATEGORY INT NULL,
    CHANGETYPE INT NULL,
    CHANGESTATUS INT NULL,
    APPROVALLEVEL INT NULL,
    COMMITTEDTOINVERTEDDATA INT NULL,
    COMMITTEDTOSOURCEDATA INT NULL,
    ENTITYTYPEID INT NULL,
    ENTITYID DECIMAL(18,0) NULL,
    USERID INT NULL,
    CHANGETIMESTAMP NVARCHAR(32) NULL,
    LASTEDITORUSERID INT NULL,
    LASTEDITORTIMESTAMP NVARCHAR(32) NULL,
    FIELDID INT NULL,
    VALUECHANGE NVARCHAR(4000) NULL,
    RELENTITYTYPEID INT NULL,
    RELENTITYID DECIMAL(18,0) NULL,
    MEDIAID DECIMAL(18,0) NULL,
    METADATA NVARCHAR(255) NULL,
    CHANGECOMMENT NVARCHAR(1000)
  )

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateIREntityChanges')
  BEGIN
  INSERT INTO IRENTITYCHANGES (UNIQUECOLLECTIONID,CHANGEID,CHANGECATEGORY,CHANGETYPE,CHANGESTATUS,APPROVALLEVEL,COMMITTEDTOINVERTEDDATA,COMMITTEDTOSOURCEDATA,ENTITYTYPEID,ENTITYID,USERID,CHANGETIMESTAMP,LASTEDITORUSERID,LASTEDITORTIMESTAMP,FIELDID,VALUECHANGE,RELENTITYTYPEID,RELENTITYID,MEDIAID,METADATA) SELECT UNIQUECOLLECTIONID,CHANGEID,CHANGECATEGORY,CHANGETYPE,CHANGESTATUS,APPROVALLEVEL,COMMITTEDTOINVERTEDDATA,COMMITTEDTOSOURCEDATA,ENTITYTYPEID,ENTITYID,USERID,CHANGETIMESTAMP,LASTEDITORUSERID,LASTEDITORTIMESTAMP,FIELDID,VALUECHANGE,RELENTITYTYPEID,RELENTITYID,MEDIAID,METADATA FROM GenerateIREntityChanges;
  DROP TABLE GenerateIREntityChanges;
  END
GO

ALTER TABLE IRENTITYCHANGES
  ADD CONSTRAINT PK_IRENTITYCHANGES
  PRIMARY KEY (CHANGEID);
GO

CREATE INDEX IDX_ECHG_EIDCHSTAT
  ON IRENTITYCHANGES (ENTITYID, CHANGESTATUS);
GO

CREATE INDEX IDX_ECHG_UIDCMT
  ON IRENTITYCHANGES (UNIQUECOLLECTIONID, COMMITTEDTOINVERTEDDATA, COMMITTEDTOSOURCEDATA);
GO

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRINITIALSEARCHCRITERIA
----------------------------------------------------------------

EXECUTE IndexPkeyRemove 'IRINITIALSEARCHCRITERIA'


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ISJOINS
----------------------------------------------------------------

EXECUTE RemoveDefaultValues 'ISJOINS','JOINTYPE'

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'v4_ISJOINS')
  BEGIN
  SELECT * INTO v4_ISJOINS FROM ISJOINS



  CREATE TABLE GenerateISJOINS
  (
    UNIQUECOLLECTIONID INT NOT NULL,
    JOINID INT NOT NULL,
    STARTTABLEID INT NULL,
    STARTFIELDNAME NVARCHAR(50) NULL,
    ENDTABLEID INT NULL,
    ENDFIELDNAME NVARCHAR(50) NULL,
    NEXTJOIN INT NULL,
    JOINTYPE INT DEFAULT 1 NOT NULL
  );
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 210)
    BEGIN
    UPDATE ISJOINS SET JoinType = 1 WHERE JoinType IS NULL OR JoinType = ''
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','ISJOINS','UPDATE',210)
    END

  INSERT INTO GenerateISJOINS (UniquecollectionID, JOINID, STARTTABLEID, STARTFIELDNAME, ENDTABLEID, ENDFIELDNAME, NEXTJOIN, JOINTYPE) SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID, ISJoins.JOINID, ISJoins.STARTTABLEID, ISJoins.STARTFIELDNAME, ISJoins.ENDTABLEID, ISJoins.ENDFIELDNAME, ISJoins.NEXTJOIN, ISJoins.JOINTYPE FROM ISJoins, IRCOLLECTIONCONFIGURATIONINFO

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 530)
    BEGIN
    DROP TABLE ISJOINS
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','ISJOINS','DROP',530)
    END
  END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateISJOINS')
  BEGIN
  SELECT * INTO ISJOINS FROM GenerateISJoins
  DROP TABLE GenerateISJOINS;
  END
GO

ALTER TABLE ISJOINS
  ADD CONSTRAINT PK_ISJOINS
  PRIMARY KEY (UNIQUECOLLECTIONID, JOINID);
go


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRUSERS
----------------------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'v4_IRUSERS')
  BEGIN
  SELECT * INTO v4_IRUSERS FROM IRUSERS

  ALTER TABLE IRUSERS ADD
    City nvarchar(50),
    State nvarchar(32),
    PostalCode nvarchar(16),
    Country nvarchar(32),
    FirstName nvarchar(32),
    LastName nvarchar(50),
    CREATEDTIMESTAMP nvarchar(32)
  END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRUsers' AND COLUMN_NAME = 'FULLNAME')
  BEGIN
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 220)
    BEGIN
    UPDATE IRUsers SET LastName = FullName
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRUsers','UPDATE',220)
    END

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 230)
    BEGIN
    UPDATE IRUsers SET CREATEDTIMESTAMP = '20040616120000' WHERE CREATEDTIMESTAMP IS NULL OR CREATEDTIMESTAMP = ''
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRUsers','UPDATE',230)
    END

  ALTER TABLE IRUSERS DROP
  COLUMN FULLNAME
  END
GO

alter table IRUSERS alter column
  LASTVISITTIMESTAMP nvarchar(32)
go


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRUserGroups
----------------------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'v4_IRUserGroups')
  BEGIN
  SELECT * INTO v4_IRUserGroups FROM IRUserGroups

  CREATE TABLE GenerateIRUserGroups
    (
    UNIQUECOLLECTIONID int,
    GROUPID  int NOT NULL IDENTITY (1, 1),
    GROUPNAME  nvarchar(50),
    GROUPCODEKEY  nvarchar(50),
    PROFILEID  int,
    CONNECTIONPOOLID  int,
    CONNECTIONRESERVE  int,
    IPADDRESSRANGES  nvarchar(1000),
    BrowserIPAddressRanges  nvarchar(1000),
    CREATEDTIMESTAMP  nvarchar(32)
    );


  INSERT INTO GenerateIRUserGroups (UNIQUECOLLECTIONID,GROUPNAME,GROUPCODEKEY,PROFILEID,CONNECTIONPOOLID,CONNECTIONRESERVE,IPADDRESSRANGES,BrowserIPAddressRanges) SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID, IRUSERGROUPS.GROUPNAME,IRUSERGROUPS.GROUPCODEKEY,IRUSERGROUPS.PROFILEID,IRUSERGROUPS.CONNECTIONPOOLID,IRUSERGROUPS.CONNECTIONRESERVE,IRUSERGROUPS.IPADDRESSRANGES,IRUSERGROUPS.BrowserIPAddressRanges FROM IRUSERGROUPS, IRCOLLECTIONCONFIGURATIONINFO

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 560)
    BEGIN
    TRUNCATE TABLE IRUserGroups
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRUserGroups','TRUNCATE',560)
    END
  END
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRUSERGROUPS' AND COLUMN_NAME = 'UNIQUECOLLECTIONID')
  ALTER TABLE IRUSERGROUPS ADD
    UNIQUECOLLECTIONID int
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRUSERGROUPS' AND COLUMN_NAME = 'CREATEDTIMESTAMP')
  ALTER TABLE IRUSERGROUPS ADD
    CREATEDTIMESTAMP nvarchar(32)
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateIRUserGroups')
  BEGIN
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 90)
    BEGIN
    INSERT INTO IRUserGroups (UNIQUECOLLECTIONID, GROUPID, GROUPNAME, GROUPCODEKEY, PROFILEID, CONNECTIONPOOLID, CONNECTIONRESERVE, IPADDRESSRANGES, BrowserIPAddressRanges, CREATEDTIMESTAMP) SELECT UNIQUECOLLECTIONID, GROUPID, GROUPNAME, GROUPCODEKEY, PROFILEID, CONNECTIONPOOLID, CONNECTIONRESERVE, IPADDRESSRANGES, BrowserIPAddressRanges, CREATEDTIMESTAMP FROM GenerateIRUserGroups
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRUserGroups','INSERT',90)
    END

  DROP TABLE GenerateIRUserGroups
  END
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 240)
  BEGIN
  UPDATE IRUSERGROUPS SET CREATEDTIMESTAMP = '20040616120000' WHERE CREATEDTIMESTAMP IS NULL OR CREATEDTIMESTAMP = ''
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRUserGroups','UPDATE',240)
  END
GO

alter table IRUSERGROUPS alter column
  UNIQUECOLLECTIONID int not null
go


alter table IRUSERGROUPS alter column
  GROUPNAME nvarchar(255) not null
go

alter table IRUSERGROUPS alter column
  IPADDRESSRANGES nvarchar(4000)
go

alter table IRUSERGROUPS alter column
  BrowserIPAddressRanges nvarchar(4000)
go

EXECUTE IndexPkeyRemove 'IRUSERGROUPS'

ALTER TABLE IRUSERGROUPS
  ADD CONSTRAINT PK_IRUSERGROUPS
  PRIMARY KEY (GROUPID);
GO

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRObjectDimension
----------------------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'v4_IRObjectDimension')
  BEGIN
  SELECT * INTO v4_IRObjectDimension FROM IRObjectDimension

  CREATE TABLE GenerateIRObjectdimension
    (
    UNIQUECOLLECTIONID INT NOT NULL,
    WIDTHFIELDID INT NOT NULL,
    HEIGHTFIELDID INT NOT NULL,
    METRIC INT NOT NULL,
    WIDTHQUALIFIERFIELDID INT NULL,
    WIDTHQUALIFIERVALUE NVARCHAR(50) NULL,
    HEIGHTQUALIFIERFIELDID INT NULL,
    HEIGHTQUALIFIERVALUE NVARCHAR(50) NULL,
    WIDTHMETRICFIELDID INT NULL,
    HEIGHTMETRICFIELDID INT NULL,
    METRICNAMEMAP NVARCHAR(100) NULL
    )


  INSERT INTO GenerateIRObjectdimension (UNIQUECOLLECTIONID,WIDTHFIELDID,HEIGHTFIELDID,METRIC,WIDTHQUALIFIERFIELDID,WIDTHQUALIFIERVALUE,HEIGHTQUALIFIERFIELDID,HEIGHTQUALIFIERVALUE,WIDTHMETRICFIELDID,HEIGHTMETRICFIELDID,METRICNAMEMAP) SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID, IROBJECTDIMENSION.WIDTHFIELDID,IROBJECTDIMENSION.HEIGHTFIELDID,IROBJECTDIMENSION.METRIC,IROBJECTDIMENSION.WIDTHQUALIFIERFIELDID,IROBJECTDIMENSION.WIDTHQUALIFIERVALUE,IROBJECTDIMENSION.HEIGHTQUALIFIERFIELDID,IROBJECTDIMENSION.HEIGHTQUALIFIERVALUE,IROBJECTDIMENSION.WIDTHMETRICFIELDID,IROBJECTDIMENSION.HEIGHTMETRICFIELDID,IROBJECTDIMENSION.METRICNAMEMAP  FROM IROBJECTDIMENSION, IRCOLLECTIONCONFIGURATIONINFO

  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 540)
    BEGIN
    DROP TABLE IROBJECTDIMENSION
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IROBJECTDIMENSION','DROP',540)
    END
  END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'GenerateIRObjectdimension')
  BEGIN
  SELECT * INTO IROBJECTDIMENSION FROM GenerateIRObjectdimension
  DROP TABLE GenerateIRObjectdimension
  END
GO

alter table IROBJECTDIMENSION alter column
  UNIQUECOLLECTIONID int not null
go

ALTER TABLE IROBJECTDIMENSION
  ADD CONSTRAINT PK_IROBJECTDIMENSION
  PRIMARY KEY (UNIQUECOLLECTIONID, WIDTHFIELDID, HEIGHTFIELDID, METRIC)
go


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRMaxIDs
----------------------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'v4_IRMaxIDs')
  BEGIN
  SELECT * INTO v4_IRMaxIDs FROM IRMaxIDs

  ALTER TABLE IRMAXIDS ADD
    MaxCollectionID int,
    MaxUniqueCollectionID int,
    MaxStandardID int,
    MaxEntityTypeID int,
    MAXENTITYID decimal(18,0),
    MaxFieldID int,
    MAXTABLEID int
  END
GO

alter table IRMAXIDS alter column
  MAXBATCHID int not null;
go
alter table IRMAXIDS alter column
  MAXMEDIAID decimal(18,0) not null;
go


--MaxCollectionID
IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 250)
  BEGIN
  UPDATE IRMAXIDS SET MaxCollectionID = 0
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRMAXIDS','UPDATE',250)
  END
GO

--MaxUniqueCollectionID
IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 260)
  BEGIN
  UPDATE IRMAXIDS SET MaxUniqueCollectionID = 0
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRMAXIDS','UPDATE',260)
  END
GO

--MaxStandardID
IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 270)
  BEGIN
  UPDATE IRMAXIDS SET MaxStandardID = 0
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRMAXIDS','UPDATE',270)
  END
GO

--MaxEntityTypeID
IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 280)
  BEGIN
  UPDATE IRMAXIDS SET MaxEntityTypeID = (SELECT MAX(EntityTypeID) + 1 FROM ISEntityTypes)
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRMAXIDS','UPDATE',280)
  END
GO

--MAXENTITYID set to 0
IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 290)
  BEGIN
  UPDATE IRMAXIDS SET MAXENTITYID = 0
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRMAXIDS','UPDATE',290)
  END
GO

--MaxFieldID
IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 300)
  BEGIN
  UPDATE IRMAXIDS SET MaxFieldID = 0
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRMAXIDS','UPDATE',300)
  END
GO

--MAXTABLEID
IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 310)
  BEGIN
  UPDATE IRMAXIDS SET MaxTableID = 0
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRMAXIDS','UPDATE',310)
  END
GO

ALTER TABLE IRMAXIDS ALTER COLUMN
  MaxCollectionID int not null
go

ALTER TABLE IRMAXIDS ALTER COLUMN
  MaxUniqueCollectionID int not null
go

ALTER TABLE IRMAXIDS ALTER COLUMN
  MaxStandardID int not null
go

ALTER TABLE IRMAXIDS ALTER COLUMN
  MaxEntityTypeID int not null
go

ALTER TABLE IRMAXIDS ALTER COLUMN
  MaxFieldID int not null
go

ALTER TABLE IRMAXIDS ALTER COLUMN
  MAXTABLEID int not null
go

--ALTER TABLE IRMAXIDS
--  ADD CONSTRAINT PK_IRMAXIDS
--  PRIMARY KEY (MAXGROUPID)
--go

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'ISENTITYTYPES' AND COLUMN_NAME = 'MAXENTITYID')
  ALTER TABLE ISENTITYTYPES DROP COLUMN MAXENTITYID
GO

----------------------------------------------------------------
-- Modifications for IRLINKREPOSITORY
----------------------------------------------------------------

EXECUTE IndexPkeyRemove 'IRLINKREPOSITORY'

alter table IRLINKREPOSITORY alter column
  IMAGEID decimal(18,0);
go
alter table IRLINKREPOSITORY alter column
  OBJECTID decimal(18,0);
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRLINKREPOSITORY' AND COLUMN_NAME = 'MEDIAGROUPID')
  ALTER TABLE IRLINKREPOSITORY ADD MEDIAGROUPID int
GO

  


----------------------------------------------------------------
--Modifications for IRMEDIAINFO
----------------------------------------------------------------

EXECUTE IndexPkeyRemove 'IRMEDIAINFO'

alter table IRMEDIAINFO alter column
  MEDIAID decimal(18,0) not null;
go  
-- Primary key

ALTER TABLE IRMEDIAINFO
  ADD CONSTRAINT PK_IREDIAINFO
  PRIMARY KEY (MEDIAID);
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRMEDIAINFO' AND COLUMN_NAME = 'PROCESSEDTIMESTAMP')
  ALTER TABLE IRMEDIAINFO ADD PROCESSEDTIMESTAMP nvarchar(32)
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 320)
  BEGIN
  UPDATE IRMEDIAINFO SET PROCESSEDTIMESTAMP = '20040616120000' WHERE (PROCESSEDTIMESTAMP IS NULL) OR (PROCESSEDTIMESTAMP = '')
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRMEDIAINFO','UPDATE',320)
  END
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRMEDIAINFO' AND COLUMN_NAME = 'PUBLISHEDTIMESTAMP')
  ALTER TABLE IRMEDIAINFO ADD PUBLISHEDTIMESTAMP nvarchar(32)
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 330)
  BEGIN
  UPDATE IRMEDIAINFO SET PUBLISHEDTIMESTAMP = '20040616120000' WHERE (PUBLISHEDTIMESTAMP IS NULL) OR (PUBLISHEDTIMESTAMP = '')
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRMEDIAINFO','UPDATE',330)
  END
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRMEDIAINFO' AND COLUMN_NAME = 'SRCFILENAME')
  ALTER TABLE IRMEDIAINFO ADD SRCFILENAME nvarchar(100)
GO


--------------------------------------------------------
--Modifications for IRVERSION 
--------------------------------------------------------

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRVERSION')
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 550)
    BEGIN
    DROP TABLE IRVERSION
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRVERSION','DROP',550)
    END
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRVERSION')
  CREATE TABLE IRVERSION
  (
    VERSION NVARCHAR(10) NOT NULL,
    ISINSCRIBECOMPLIANT INT NULL,
    IsPersonalCollectionServer INT NULL
  );

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRVERSION')
  BEGIN
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 70)
    BEGIN
    INSERT INTO IRVersion(Version, ISINSCRIBECOMPLIANT, IsPersonalCollectionServer) VALUES('5', 1, 0);
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRVersion','INSERT',70)
    END
  END
-- Primary key

ALTER TABLE IRVERSION
  ADD CONSTRAINT PK_IRVERSION
  PRIMARY KEY (VERSION);
go


------------------------------------------------
-- Create Table Statements for ISCOLLECTIONENTITYMAP
------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'ISCOLLECTIONENTITYMAP')
  CREATE TABLE ISCOLLECTIONENTITYMAP
  (
    UNIQUECOLLECTIONID INT NOT NULL,
    ENTITYTYPEID INT NOT NULL,
    ENTITYID DECIMAL(18,0) NOT NULL
  );

-- Primary key

ALTER TABLE ISCOLLECTIONENTITYMAP
  ADD CONSTRAINT PK_ISCOLLECTIONENTITYMAP
  PRIMARY KEY (ENTITYTYPEID, ENTITYID); 
go

------------------------------------------------
--Modifications for DTHIERARCHYNODERELATIONS
------------------------------------------------

EXECUTE IndexPkeyRemove 'DTHIERARCHYNODERELATIONS'

ALTER TABLE DTHIERARCHYNODERELATIONS
  ADD CONSTRAINT PK_HIERNODERELGROUP
  PRIMARY KEY (HIERARCHYID, HIERARCHYINDEX, RELHIERARCHYINDEX, RELATIONTYPEID);
go

------------------------------------------------
--Modifications for DTHIERARCHYNODES
--Modifications for ITHIERARCHYNODES
------------------------------------------------

EXECUTE IndexPkeyRemove 'DTHIERARCHYNODES'
EXECUTE IndexPkeyRemove 'ITHIERARCHYNODES'

ALTER TABLE DTHIERARCHYNODES alter column
  VALUETEXT nvarchar(4000);
go

alter table DTHIERARCHYNODES alter column
  VALUEID decimal(18,0)
go

  -- Primary key

ALTER TABLE DTHIERARCHYNODES
  ADD CONSTRAINT PK_DTHIERARCHYNODES
  PRIMARY KEY (HIERARCHYID, HIERARCHYINDEX);
go

alter table ITHIERARCHYNODES alter column
  VALUEID decimal(18,0)
go

ALTER TABLE ITHIERARCHYNODES alter column
  VALUETEXT nvarchar(4000);
go
  -- Primary key

ALTER TABLE ITHIERARCHYNODES
  ADD CONSTRAINT PK_ITHIERARCHYNODES
  PRIMARY KEY (HIERARCHYID, HIERARCHYINDEX);
go

----------------------------------------------------
-- Modifications for DTVALUEHIERARCHY
----------------------------------------------------

EXECUTE IndexPkeyRemove 'DTVALUEHIERARCHY'

alter table DTVALUEHIERARCHY alter column
  VALUEID decimal(18,0) not null
go

alter table DTVALUEHIERARCHY add
  constraint PK_DTVALUEHIERARCHY primary key(VALUEID)
go


----------------------------------------------------
-- Modifications for DTHIERARCHYTOOBJECT
----------------------------------------------------

EXECUTE IndexPkeyRemove 'DTHIERARCHYTOOBJECT'

alter table DTHIERARCHYTOOBJECT alter column
  OBJECTID decimal(18,0) not null;
go 
-- Primary key

ALTER TABLE DTHIERARCHYTOOBJECT
  ADD CONSTRAINT PK_DTHIERARCHYTOOBJECT
  PRIMARY KEY (OBJECTID, HIERARCHYID, HIERARCHYINDEX);
go

------------------------------------------------
--Modification for DTTERMS
------------------------------------------------

TRUNCATE TABLE DTTERMS;

EXECUTE IndexPkeyRemove 'DTTERMS'

alter table DTTERMS alter column
  KEYWORD nvarchar(255);
go
-- Primary key

ALTER TABLE DTTERMS
  ADD CONSTRAINT PK_DTTERMS
  PRIMARY KEY (TERMID);
go

CREATE INDEX IDX_DTTERMS_KEYWD
  ON DTTERMS (KEYWORD);

------------------------------------------------
-- Create Table Statements for IDKEYWORDS
------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IDKEYWORDS')
  CREATE TABLE IDKEYWORDS
  (
    ID INT NOT NULL,
    KEYWORD NVARCHAR(255) NULL
  );

-- Primary key

ALTER TABLE IDKEYWORDS
  ADD CONSTRAINT PK_IDKEYWORDS
  PRIMARY KEY (ID);
go
------------------------------------------------
--Modifications for IDTEMPNEW
------------------------------------------------

alter table IDTEMPNEW alter column
  OBJECTID decimal(18,0) not null;
go

alter table IDTEMPNEW alter column
  VALUETEXT nvarchar(4000);
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IDTEMPNEW' AND COLUMN_NAME = 'VALUEDATE')
  ALTER TABLE IDTEMPNEW ADD
    VALUEDATE nvarchar(50);
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IDTEMPNEW' AND COLUMN_NAME = 'GROUPING')
  ALTER TABLE IDTEMPNEW ADD
    GROUPING decimal(18,0);
GO

alter table IDTEMPNEW alter column
  GROUPING decimal(18,0);
go

alter table IDTEMPNEW alter column
  PREFERRED int;
go
-- Primary key

ALTER TABLE IDTEMPNEW
  ADD CONSTRAINT PK_IDTEMPNEW1
  PRIMARY KEY (OBJECTID);
go
------------------------------------------------
--Modifications for IDTEMPOLD 
------------------------------------------------ 

alter table IDTEMPOLD alter column
  OBJECTID decimal(18,0) not null;
go
alter table IDTEMPOLD alter column
  VALUETEXT nvarchar(4000);
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IDTEMPOLD' AND COLUMN_NAME = 'VALUEDATE')
  ALTER TABLE IDTEMPOLD ADD
    VALUEDATE nvarchar(50);
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IDTEMPOLD' AND COLUMN_NAME = 'GROUPING')
  ALTER TABLE IDTEMPOLD ADD
    GROUPING decimal(18,0);
GO

alter table IDTEMPOLD alter column
  GROUPING decimal(18,0);
go
alter table IDTEMPOLD alter column
  PREFERRED int;
go
-- Primary key

ALTER TABLE IDTEMPOLD
  ADD CONSTRAINT PK_IDTEMPOLD1
  PRIMARY KEY (OBJECTID);
go 

------------------------------------------------
-- Create Table Statements for IRCOLLECTIONMEDIAMAP
------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRCOLLECTIONMEDIAMAP')
  BEGIN
  CREATE TABLE IRCOLLECTIONMEDIAMAP
  (
    UNIQUECOLLECTIONID INT NOT NULL,
    MEDIAID DECIMAL(18,0) NOT NULL
  );
  IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 80)
    BEGIN
    INSERT INTO IRCollectionMediaMap(UNIQUECOLLECTIONID, MEDIAID) SELECT DISTINCT UniqueCollectionID, ImageID AS MediaID FROM IRGroupImageMap INNER JOIN IRGroups ON IRGroups.GroupID = IRGroupImageMap.GroupID WHERE IRGroups.GroupType = 1;  
    INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','IRCollectionMediaMap','INSERT',80)
    END
  END
GO
-- Primary key

ALTER TABLE IRCOLLECTIONMEDIAMAP
  ADD CONSTRAINT PK_IRCOLLECTIONMEDIAMAP
  PRIMARY KEY (UNIQUECOLLECTIONID, MEDIAID);
GO

------------------------------------------------  
--Modification for IRENTITYLOCKS  
------------------------------------------------

EXECUTE IndexPkeyRemove 'IRENTITYLOCKS'

alter table IRENTITYLOCKS alter column
  ENTITYID DECIMAL(18,0) NOT NULL;
go

alter table IRENTITYLOCKS alter column
  LOCKTIMESTAMP nvarchar(32);
go

-- Primary key

ALTER TABLE IRENTITYLOCKS
  ADD CONSTRAINT PK_IRENTITYLOCKS
  PRIMARY KEY (ENTITYTYPEID, ENTITYID);
go
------------------------------------------------
-- Modifications for IRENTITYMEDIAMAP
------------------------------------------------

EXECUTE IndexPkeyRemove 'IRENTITYMEDIAMAP'

alter table IRENTITYMEDIAMAP alter column
  ENTITYID DECIMAL(18,0) NOT NULL;
go
alter table IRENTITYMEDIAMAP alter column
  MEDIAID DECIMAL(18,0) NOT NULL;
go
-- Primary key

ALTER TABLE IRENTITYMEDIAMAP
  ADD CONSTRAINT PK_IRENTITYMEDIAMAP
  PRIMARY KEY (ENTITYTYPEID, ENTITYID, MEDIAID);
go

CREATE INDEX IDX_ENTMED_MEDID
  ON IRENTITYMEDIAMAP (MEDIAID);

------------------------------------------------
--Modification for IRFIELDS
------------------------------------------------

alter table IRFIELDS alter column
  DISPLAYNAME nvarchar(100);
go

alter table IRFIELDS alter column
  FIELDNAME nvarchar(100);
go  

UPDATE IRFIELDS SET FIELDTYPE = 1 WHERE FIELDTYPE = 0 OR FIELDTYPE = 3

------------------------------------------------
--Modifications for IRIMAGEFILES
------------------------------------------------ 

EXECUTE IndexPkeyRemove 'IRImageFiles'

alter table IRImageFiles alter column
  IMAGEID decimal(18,0) not null
go

alter table IRImageFiles alter column
  FILENAME nvarchar(255)
go
  
-- Primary key

ALTER TABLE IRIMAGEFILES
  ADD CONSTRAINT PK_IRIMAGEFILES
  PRIMARY KEY (IMAGEID, RESOLUTIONSIZE, FORMAT, MEDIATYPE);
go

CREATE INDEX IDX_IRIMGEFLS_IMIDLPSFMTRESMED
  ON IRIMAGEFILES (IMAGEID, LPSID, FORMAT, RESOLUTIONSIZE, MEDIATYPE);

CREATE INDEX IDX_IRIMGEFLS_FMTRESMEDLPSIMD
  ON IRIMAGEFILES (FORMAT, RESOLUTIONSIZE, MEDIATYPE, LPSID, IMAGEID, WIDTH, HEIGHT, FILENAME);
  
------------------------------------------------  
--Modifications for IRImageToDocumentMap 
------------------------------------------------

EXECUTE IndexPkeyRemove 'IRImageToDocumentMap'

alter table IRImageToDocumentMap alter column
  IMAGEID decimal(18,0) not null;
go  
ALTER TABLE IRIMAGETODOCUMENTMAP
  ADD CONSTRAINT PK_IRIMAGETODOCUMENTMAP
  PRIMARY KEY (IMAGEID, DOCUMENTID);
go  
----------------------------------------------------------------   
--Modifications for IRObjectImageMap 
---------------------------------------------------------------- 

EXECUTE IndexPkeyRemove 'IRObjectImageMap'

alter table IRObjectImageMap alter column
  OBJECTID decimal(18,0) not null;
go
alter table IRObjectImageMap alter column
  IMAGEID decimal(18,0) not null;
go  
-- Primary key

ALTER TABLE IROBJECTIMAGEMAP
  ADD CONSTRAINT PK_IROBJECTIMAGEMAP
  PRIMARY KEY (OBJECTID, IMAGEID);
go
CREATE INDEX IDX_IROBJIMGMP_IMGID
  ON IROBJECTIMAGEMAP (IMAGEID);
  
------------------------------------------------
-- MODIFICATIONS for IRPROFILE
------------------------------------------------

EXECUTE IndexPkeyRemove 'IRPROFILE'

-- Primary key

ALTER TABLE IRPROFILE
  ADD CONSTRAINT PK_IRPROFILE
  PRIMARY KEY (PROFILEID, COLLECTIONID, SPSNUM);
GO

------------------------------------------------
-- Create Table Statements for IRVOCABULARIES
------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRVOCABULARIES')
  CREATE TABLE IRVOCABULARIES
  (
    FIELDID INT NULL,
    VOCABVALUEID INT NULL,
    VOCABVALUE NVARCHAR(255) NULL
  );


------------------------------------------------
-- Create Table Statements for IRVOCABULARY
------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IRVOCABULARY')
  CREATE TABLE IRVOCABULARY
  (
    VOCABULARYID INT NOT NULL,
    FIELDNAME NVARCHAR(50) NULL,
    TABLENAME NVARCHAR(50) NULL,
    VOCABVALUE NVARCHAR(50) NULL
  );

-- Primary key

ALTER TABLE IRVOCABULARY
  ADD CONSTRAINT PK_IRVOCABULARY
  PRIMARY KEY (VOCABULARYID);
go

------------------------------------------------
--Modifications for ISDOCUMENTPAGES
------------------------------------------------

alter table ISDOCUMENTPAGES alter column
  OBJECTID decimal(18,0) not null;
go
alter table ISDOCUMENTPAGES alter column
  IMAGEID decimal(18,0) not null;
go

alter table ISDOCUMENTS alter column
  DOCUMENTNAME nvarchar(850);
go
alter table ISDOCUMENTS alter column
  IDENTITYVALUE nvarchar(4000);
go
alter table ISENTITYFIELDS alter column
  ISREQUIRED int;
go
alter table ISENTITYFIELDS alter column
  ISVALUELISTALLOWED int;
go
alter table ISENTITYFIELDS alter column
  REPEATVALUESALLOWED int;
go
alter table ISENTITYFIELDS alter column
  DISPLAYINRELATEDENTITIES int;
go
alter table ISENTITYFIELDS alter column
  ALWAYSVALIDATENEWVALUES int;
go
alter table ISENTITYTYPES alter column
  ISVOCABULARY int;
go
alter table ISENTITYTYPES alter column
  ISDEPENDENT int;
go
alter table ISENTITYTYPES alter column
  ISDUPECHECKENABLED int;
go
alter table ISENTITYTYPES alter column
  ISREFCHECKENABLED int;
go
alter table ISENTITYTYPES alter column
  ISPREFERREDENTITY int;
go

ALTER TABLE ISHIERARCHIES
  ADD CONSTRAINT PK_ISHIERARCHY
  PRIMARY KEY (HIERARCHYID);
go

------------------------------------------------------
-- Modifications for ISSTOPLIST
------------------------------------------------------

EXECUTE IndexPkeyRemove 'ISSTOPLIST'

ALTER TABLE ISSTOPLIST
  ADD CONSTRAINT PK_ISSTOPLIST
  PRIMARY KEY (TERM);
go

alter table ISTABLES alter column
  HIERARCHY int;
go
alter table ISTABLES alter column
  PARENTCHILD int;
go

------------------------------------------------------
-- Modifications for ITHIERARCHYTOOBJECT
------------------------------------------------------

EXECUTE IndexPkeyRemove 'ITHIERARCHYTOOBJECT'

alter table ITHIERARCHYTOOBJECT alter column
  OBJECTID decimal(18,0) not null;
go  
-- Primary key

ALTER TABLE ITHIERARCHYTOOBJECT
  ADD CONSTRAINT PK_ITHIERARCHYTOOBJECT
  PRIMARY KEY (OBJECTID, HIERARCHYID, HIERARCHYINDEX);
go
  

-----------------------------------------------------
--Modification for ITTERMS
-----------------------------------------------------

TRUNCATE TABLE ITTERMS;

EXECUTE IndexPkeyRemove 'ITTERMS'

alter table ITTERMS alter column
  KEYWORD nvarchar(255);
go

-- Primary key

ALTER TABLE ITTERMS
  ADD CONSTRAINT PK_ITTERMS
  PRIMARY KEY (TERMID);
go

CREATE INDEX IDX_ITTERMS_KEYWD
  ON ITTERMS (KEYWORD);
go
  
--------------------------------------------------------
--Modifications for SLSTANDARDSLOOKUP
--------------------------------------------------------

EXECUTE IndexPkeyRemove 'SLSTANDARDSLOOKUP'

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SLSTANDARDSLOOKUP' AND COLUMN_NAME = 'PARENTSTANDARDID')
  alter table SLSTANDARDSLOOKUP add
    PARENTSTANDARDID int;
GO

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SLSTANDARDSLOOKUP' AND COLUMN_NAME = 'ISTEMPLATE')
  alter table SLSTANDARDSLOOKUP add
    ISTEMPLATE INT;
GO

--update SLSTANDARDSLOOKUP set PARENTSTANDARDID = (SELECT StandardID FROM  SLStandardsLookup WHERE (Standard_Type = 1));
IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 340)
  BEGIN
  UPDATE SLSTANDARDSLOOKUP SET PARENTSTANDARDID = StandardID WHERE Standard_Type = 1 OR Standard_Type = 2 OR Standard_Type = 3
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDSLOOKUP','UPDATE',340)
  END
GO

alter table SLSTANDARDSLOOKUP alter column
  PARENTSTANDARDID int not null;
go
alter table SLSTANDARDSLOOKUP alter column
  VERSION_INFO nvarchar(255);
go

alter table SLSTANDARDSLOOKUP alter column
  STANDARDNAME nvarchar(255)
go

alter table SLSTANDARDSLOOKUP alter column
  STANDARDDESCRIPTIONURL nvarchar(255);
go

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 350)
  BEGIN
  update SLSTANDARDSLOOKUP set ISTEMPLATE = 1 where SLSTANDARDSLOOKUP.Standard_Type = 1;
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDSLOOKUP','UPDATE',350)
  END
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 360)
  BEGIN
  update SLSTANDARDSLOOKUP set ISTEMPLATE = 0 where SLSTANDARDSLOOKUP.Standard_Type <> 1;
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDSLOOKUP','UPDATE',360)
  END
GO

alter table SLSTANDARDSLOOKUP alter column
  ISTEMPLATE int not null;
go

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SLSTANDARDSLOOKUP' AND COLUMN_NAME = 'ISPCTEMPLATE' AND COLUMN_NAME = 'ISPUBLISHEDTEMPLATE' AND COLUMN_NAME = 'CREATEDTIMESTAMP')
  alter table SLSTANDARDSLOOKUP add
    ISPCTEMPLATE int,
    ISPUBLISHEDTEMPLATE int,
    CREATEDTIMESTAMP nvarchar(32);
go

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 370)
  BEGIN
  update SLSTANDARDSLOOKUP set ISPCTEMPLATE = 0;
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDSLOOKUP','UPDATE',370)
  END
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 380)
  BEGIN
  update SLSTANDARDSLOOKUP set ISPUBLISHEDTEMPLATE = 1 where SLSTANDARDSLOOKUP.Standard_Type = 1;
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDSLOOKUP','UPDATE',380)
  END
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 390)
  BEGIN
  update SLSTANDARDSLOOKUP set ISPUBLISHEDTEMPLATE = 0 where SLSTANDARDSLOOKUP.Standard_Type <> 1;
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDSLOOKUP','UPDATE',390)
  END
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 400)
  BEGIN
  UPDATE SLSTANDARDSLOOKUP SET CREATEDTIMESTAMP = '20040616120000' WHERE (CREATEDTIMESTAMP IS NULL) OR (CREATEDTIMESTAMP = '')
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDSLOOKUP','UPDATE',400)
  END
GO

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SLSTANDARDSLOOKUP' AND COLUMN_NAME = 'Enabled')
  ALTER TABLE SLSTANDARDSLOOKUP DROP
    column Enabled;
go
-- Primary key

ALTER TABLE SLSTANDARDSLOOKUP
  ADD CONSTRAINT PK_SLSTANDARDSLOOKUP
  PRIMARY KEY (STANDARDID);
go
------------------------------------------------
-- Create Table Statements for
------------------------------------------------

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SLSTANDARDSRELATIONS')
  CREATE TABLE SLSTANDARDSRELATIONS
  (
    STANDARDID INT NOT NULL,
    RELATEDSTANDARDID INT NOT NULL
  );

-- Primary key

ALTER TABLE SLSTANDARDSRELATIONS
  ADD CONSTRAINT PK_SLSTANDARDSRELATIONS
  PRIMARY KEY (STANDARDID, RELATEDSTANDARDID);
go
  
------------------------------------------------
-- Modifications for IAADMINISTRATIONACCOUNTS
------------------------------------------------

EXECUTE IndexPkeyRemove 'IAADMINISTRATIONACCOUNTS'

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'IAADMINISTRATIONACCOUNTS' AND COLUMN_NAME = 'CREATEDTIMESTAMP')
  ALTER TABLE IAADMINISTRATIONACCOUNTS ADD
    CREATEDTIMESTAMP varchar(32)
GO

ALTER TABLE IAADMINISTRATIONACCOUNTS ALTER COLUMN
    UserName NVARCHAR(50) not null
GO

-- Primary key

ALTER TABLE IAADMINISTRATIONACCOUNTS
  ADD CONSTRAINT PK_IADMNSTRACCNTS
  PRIMARY KEY (ADMINID);
go

CREATE UNIQUE INDEX IDX_IADMNACCNTS_UN
  ON IAADMINISTRATIONACCOUNTS (USERNAME);
go


-----------------------------------------------------
--Modification for IRLPS
-----------------------------------------------------

EXECUTE IndexPkeyRemove 'IRLPS'

alter table IRLPS alter column
  LPS nvarchar(255)
go

-- Primary key

ALTER TABLE IRLPS
  ADD CONSTRAINT PK_IRLPS
  PRIMARY KEY (LPSID);
go
  
-----------------------------------------------------
--Modification for ITSEARCHRESULTS
-----------------------------------------------------

EXECUTE IndexPkeyRemove 'ITSEARCHRESULTS'

TRUNCATE TABLE ITSEARCHRESULTS

alter table ITSEARCHRESULTS alter column
  OBJECTID decimal(18,0) not null;
go

alter table ITSEARCHRESULTS alter column
  MEDIAID decimal(18,0);
go

ALTER TABLE ITSEARCHRESULTS ALTER COLUMN
  CriteriaID INT NULL;
GO

-- Primary key

CREATE INDEX IDX_ITSRCHRSLTS_SRCHOBJ
  ON ITSEARCHRESULTS (SEARCHQUERYID, OBJECTID);
  

-----------------------------------------------------
--Modification for ITVALUEHIERARCHY
-----------------------------------------------------  
EXECUTE IndexPkeyRemove 'ITVALUEHIERARCHY'

-- Primary key
alter table ITVALUEHIERARCHY alter column
  VALUEID decimal(18,0) not null
go

ALTER TABLE ITVALUEHIERARCHY
  ADD CONSTRAINT PK_ITVALUEHIERARCHY1
  PRIMARY KEY (VALUEID);
go


-----------------------------------------------------
--Modification for SLSTANDARDSSTARTUP
-----------------------------------------------------  

IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SLSTANDARDSSTARTUP' AND COLUMN_NAME = 'StandardName')
  alter table SLSTANDARDSSTARTUP drop
    column StandardName;
go

-----------------------------------------------------
--Modification for SLSTANDARDFIELDS
-----------------------------------------------------
EXECUTE IndexPkeyRemove 'SLSTANDARDFIELDS'

alter table SLSTANDARDFIELDS alter column
  STANDARDNAME nvarchar(255)
go

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 410)
  BEGIN
  UPDATE SLSTANDARDFIELDS SET STANDARDFIELDNAME = 'CREATION-COMMISSION-COMMISSIONER' WHERE (STANDARDID = 0) AND (STANDARDFIELDID = 124);
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDFIELDS','UPDATE',410)
  END
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 420)
  BEGIN
  UPDATE SLSTANDARDFIELDS SET STANDARDFIELDNAME = 'Title' WHERE (STANDARDID = 2) AND (STANDARDFIELDID = 3);
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDFIELDS','UPDATE',420)
  END
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 430)
  BEGIN
  UPDATE SLSTANDARDFIELDS SET STANDARDFIELDNAME = 'Context/Archaeological' WHERE (STANDARDID = 5) AND (STANDARDFIELDID = 77);
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDFIELDS','UPDATE',430)
  END
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 440)
  BEGIN
  UPDATE SLSTANDARDFIELDS SET STANDARDFIELDDISPLAYNAME = 'CREATION-COMMISSION-COMMISSIONER' WHERE (STANDARDID = 0) AND (STANDARDFIELDID = 124);
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDFIELDS','UPDATE',440)
  END
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 450)
  BEGIN
  UPDATE SLSTANDARDFIELDS SET STANDARDFIELDDISPLAYNAME = 'Title' WHERE (STANDARDID = 2) AND (STANDARDFIELDID = 3);
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDFIELDS','UPDATE',450)
  END
GO

IF NOT EXISTS (SELECT * FROM INSIGHTUPGRADELOG WHERE ChangeIdentifier = 460)
  BEGIN
  UPDATE SLSTANDARDFIELDS SET STANDARDFIELDDISPLAYNAME = 'Context/Archaeological' WHERE (STANDARDID = 5) AND (STANDARDFIELDID = 77);
  INSERT INTO INSIGHTUPGRADELOG (Version,TableName,ChangeType,ChangeIdentifier) VALUES ('5.0','SLSTANDARDFIELDS','UPDATE',460)
  END
GO

-- Primary key

ALTER TABLE SLSTANDARDFIELDS
  ADD CONSTRAINT PK_SLSTANDARDFIELDS
  PRIMARY KEY (STANDARDID, STANDARDFIELDID);
go

DROP PROCEDURE IndexPkeyRemove
go

DROP PROCEDURE RemoveDefaultValues
go

------------------------------------------
--Media Server SPS Creation
------------------------------------------
DECLARE @OrigSPSNum INT
DECLARE @NewSPSNum INT
DECLARE @NewResolutionSize INT
DECLARE @NewMediaType INT
DECLARE @NewCollectionID INT
DECLARE @NewFormat NVARCHAR(10)
DECLARE @OrigURL NVARCHAR(255)
DECLARE @NewURL NVARCHAR(255)
DECLARE @MaxSPSNum INT

SET @MaxSPSNum = (SELECT MAX(SPSNUM) FROM IRSPS)

DECLARE DistinctSPS CURSOR
  FOR SELECT DISTINCT SPSNUM FROM IRSPS
OPEN DistinctSPS

FETCH NEXT FROM DistinctSPS INTO @OrigSPSNum
WHILE @@FETCH_STATUS = 0
  BEGIN
  SET @NewSPSNum = @OrigSPSNum + @MaxSPSNum

  --ADD New JPEG References
  DECLARE CurrentSPS CURSOR
    FOR SELECT RESOLUTIONSIZE, MEDIATYPE, COLLECTIONID, FORMAT, URL FROM IRSPS WHERE SPSNUM = @OrigSPSNum AND FORMAT = 'JPEG' ORDER BY MEDIATYPE, RESOLUTIONSIZE
  OPEN CurrentSPS

  FETCH FROM CurrentSPS INTO @NewResolutionSize, @NewMediaType, @NewCollectionID, @NewFormat, @OrigURL
  WHILE @@FETCH_STATUS = 0
    BEGIN
    SET @NewURL = 'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size' + CAST(@NewResolutionSize AS VARCHAR)
    INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,@NewResolutionSize,@NewMediaType,@NewCollectionID,@NewFormat,@NewURL)
    FETCH FROM CurrentSPS INTO @NewResolutionSize, @NewMediaType, @NewCollectionID, @NewFormat, @OrigURL
    END
  CLOSE CurrentSPS
  DEALLOCATE CurrentSPS

  --ADD New SID References
  DECLARE CurrentSPS CURSOR
    FOR SELECT RESOLUTIONSIZE, MEDIATYPE, COLLECTIONID, FORMAT, SUBSTRING(URL,8,255) from IRSPS where SPSNUM = @OrigSPSNum and FORMAT = 'SID' ORDER BY MEDIATYPE, RESOLUTIONSIZE
  OPEN CurrentSPS

  FETCH FROM CurrentSPS INTO @NewResolutionSize, @NewMediaType, @NewCollectionID, @NewFormat, @OrigURL
  WHILE @@FETCH_STATUS = 0
    BEGIN
    SET @NewURL = 'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=' + @OrigURL
    INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,@NewResolutionSize,@NewMediaType,@NewCollectionID,@NewFormat,@NewURL)
    FETCH FROM CurrentSPS INTO @NewResolutionSize, @NewMediaType, @NewCollectionID, @NewFormat, @OrigURL
    END
  CLOSE CurrentSPS
  DEALLOCATE CurrentSPS

  --Add JP2 references
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,5,1,@NewCollectionID,'JP2','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/JP2K')
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,6,1,@NewCollectionID,'JP2','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/JP2K')
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,7,1,@NewCollectionID,'JP2','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/JP2K')
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,8,1,@NewCollectionID,'JP2','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/JP2K')

  --Add AUDIO references
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,0,2,@NewCollectionID,'AUDIO','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size0')
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,1,2,@NewCollectionID,'AUDIO','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size1')
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,2,2,@NewCollectionID,'AUDIO','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size2')

  --Add VIDEO references
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,0,3,@NewCollectionID,'VIDEO','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size0')
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,1,3,@NewCollectionID,'VIDEO','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size1')
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,2,3,@NewCollectionID,'VIDEO','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size2')

  --Add QTVR references
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,0,4,@NewCollectionID,'QTVR','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size0')
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,1,4,@NewCollectionID,'QTVR','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size1')
  INSERT INTO IRSPS (SPSNUM,RESOLUTIONSIZE,MEDIATYPE,COLLECTIONID,FORMAT,URL) VALUES (@NewSPSNum,2,4,@NewCollectionID,'QTVR','http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size2')

  FETCH NEXT FROM DistinctSPS INTO @OrigSPSNum
  END
CLOSE DistinctSPS
DEALLOCATE DistinctSPS

------------------------------------------
--Insert Any Missing FieldGroupID (required for Insight Studio)
------------------------------------------

INSERT INTO IRFIELDGROUPS SELECT ISEntityTypes.EntityTypeID AS FieldGroupID, 0 AS CollectionID, ISEntityTypes.EntityTypeName + ' v5_Upgrade' AS DisplayName, 
            2 AS FieldGroupType, 10000 AS DisplayOrder
FROM ISEntityTypes LEFT OUTER JOIN
       IRFieldGroups ON ISEntityTypes.EntityTypeID = IRFieldGroups.FieldGroupID
WHERE     (IRFieldGroups.FieldGroupID IS NULL);
